@@ -17,9 +17,12 @@ if (eregi("servizi.php",$_SERVER['PHP_SELF'])) {
     die();
 }
 
-
-?>
-<a href="index.php?mod=none_Segnala_News">Segnala News</a><br>
-<a href="index.php?mod=none_Search">Ricerca</a><br>
-<a href="index.php?mod=none_Headlines">Headlines</a><br>
-<a href="index.php?mod=none_Backend">Backend</a><br>
+if (user_can_view_section("none_Segnala_News"))
+	echo "&#187;&nbsp;<a href=\"index.php?mod=none_Segnala_News\" title=\""._GOTOSECTION.": "._SEGNEWS."\">"._SEGNEWS."</a><br />";
+if (user_can_view_section("none_Search"))
+	echo "&#187;&nbsp;<a href=\"index.php?mod=none_Search\" title=\""._GOTOSECTION.": "._CERCA."\">"._CERCA."</a><br />";
+if (user_can_view_section("none_Headlines"))
+	echo "&#187;&nbsp;<a href=\"index.php?mod=none_Headlines\" title=\""._GOTOSECTION.": Headlines\">Headlines</a><br />";
+if (user_can_view_section("none_Backend"))
+	echo "&#187;&nbsp;<a href=\"index.php?mod=none_Backend\" title=\""._GOTOSECTION.": Backend\">Backend</a><br />";
+?>
\ No newline at end of file
