@@ -1,4 +1,4 @@
-<? 
+<?
 
 /************************************************************************/
 /* FlatNuke - Flat Text Based Content Management System                 */
@@ -18,15 +18,24 @@ if (eregi("cerca.php",$_SERVER['PHP_SELF'])) {
     die();
 }
 
+// configuration
+$search_plugins_dir = "include/search/";
+$GLOBALS['search_plugins_dir'] = $search_plugins_dir;
+$search_section = "none_Search";
+
 ?>
-<div align="center">
-<form action="index.php" method="GET">
-<input type="hidden" name="mod" value="none_Search">
-<input type="text" name="find" size="16"><br><br>
-<select name="where">
-<option value="news" selected>News</option>
-<option value="forum/topics">Forum</option>
-</select><br><br>
-<input type="submit" value="<?=_CERCA?>">
+<div style="text-align:center; margin-bottom:0.5em;">
+<form action="index.php?mod=<?=$search_section?>" method="post">
+	<input type="hidden" name="method" value="AND" />
+	<input type="hidden" name="mod" value="<?=$search_section?>" />
+	<input type="hidden" name="where" value="allsite" />
+	<input type="text" name="find" size="10" id="text" />
+	<input type="submit" value="<?=_CERCA?>" />
 </form>
 </div>
+<div style="margin-bottom:0.5em;">
+<?=_SEARCHDESC?>
+</div>
+<div style="text-align:center">
+<a href="index.php?mod=<?=$search_section?>" title="<?=_GOTOSECTION?>: <?=_CERCA?>"><?=_ADVSEARCH?></a>
+</div>
