@@ -30,10 +30,11 @@ if (eregi("Statistiche.php",$_SERVER['PHP_SELF'])) {
     Header("Location: ../../index.php");
     die();
 }
+
 if(file_exists("misc/flatstat/totale.php")){
-$fd = file ("misc/flatstat/totale.php");
-echo "Visite: $fd[0] <br>
-<center><a href=\"index.php?mod=none_Statistiche\">Statistiche</a></center>";
+	$fd = file ("misc/flatstat/totale.php");
+	echo "Visite: $fd[0] <br />";
+	echo "<div style=\"text-align : center;\"><a href=\"index.php?mod=none_Statistiche\" title=\""._GOTOSECTION.": Statistiche\">Statistiche</a></div>";
 }
 ?>
 
