@@ -178,6 +178,18 @@ if (file_exists("include/redefine/".__FUNCTION__.".php")){
 			return;
 		}
 
+		/*
+		 * Apre il relativo file di descrizione "<$filename>.descrizione"
+		 * se non esiste lo creo io.
+		 */
+		if (!file_exists($filename.".description")){
+			$data = array();
+			$data['time'] = filemtime($filename);
+			save_description($filename,$data);
+
+		}
+
+
 		/* Calcola la grandezza del file */
 		$size="";
 		$size = round(filesize($filename)/1024)."Kb";
@@ -185,15 +197,6 @@ if (file_exists("include/redefine/".__FUNCTION__.".php")){
 		$lastupdate="";
 		$lastupdate = date(_FDDATEFORMAT, getfiletime($filename) );
 
-		/*
-		 * Apre il relativo file di descrizione "<$filename>.descrizione"
-		 * se non esiste lo creo io.
-		 */
-		if (!file_exists($filename.".description")){
-			save_description($filename,array());
-
-		}
-
 		//NUOVA FUNZIONE PER IL CARICAMENTO DELLA DESCRIZIONE
 		$description=array();
 		$description= load_description($filename);
@@ -230,13 +233,13 @@ if (file_exists("include/redefine/".__FUNCTION__.".php")){
 		/* Generazione Tabella */
 		echo "<br /><br />";
 		if (ltrim($description['name'])==""){
-			$string_title = "<a id=\"".basename($filename)."\" title=\"mime icon\">".getIcon($ext,$icon_style)."</a>".basename($filename);
+			$string_title = "<a id=\"".create_id($filename)."\" title=\"mime icon\">".getIcon($ext,$icon_style)."</a>".basename($filename);
 			if ($description['hide']=="true") $string_title = "<span style=\"color : #ff0000; text-decoration : line-through;\">".$string_title."</span>";
 			OpenTableTitle($string_title.$newfilestring);
 		}
 
 		else if (ltrim($description['name'])!=""){
-			$string_title = "<a id=\"".basename($filename)."\">".getIcon($ext,$icon_style)."</a>".$description['name'];
+			$string_title = "<a id=\"".create_id($filename)."\">".getIcon($ext,$icon_style)."</a>".$description['name'];
 			if ($description['hide']=="true") $string_title = "<span style=\"color : #ff0000; text-decoration : line-through;\">".$string_title."</span>";
 			OpenTableTitle("$string_title".$newfilestring);
 		}
@@ -369,7 +372,21 @@ if (file_exists("include/redefine/".__FUNCTION__.".php")){
 
 				<?
 			}
+			
+			echo "<tr>";
+			echo "<td style=\"vertical-align : top;\">";
+			echo "<b>"._FDRATING."&nbsp;</b>";//$voteaverage";
+			echo "<br />(<i>".$description['totalvote']." "._FDVOTES."</i>)";
+			echo "</td>";
+			
+			echo "<td style=\"vertical-align : top;\">";
+			
 			fd_show_vote($filename);
+			
+			echo "</td>";
+
+			echo "</tr>";
+			
 			//inserisco i plugin
 			fd_load_php_code("download/include/autoinclude/fd_view_file/footer/"); ?>
 
@@ -547,7 +564,7 @@ if ($myforum!="" and !is_alphanumeric($myforum)) return;
 				$file = eregi_replace("\.description$","",$file);
 				if (!fd_user_can_view_file($file)) continue;
 				$desc = load_description($file);
-				echo "<br />&nbsp;&nbsp;&nbsp;&#187;&nbsp;<a href=\"index.php?mod=".rawurlencodepath(eregi_replace("^sections/","",$dir))."#".rawurlencodepath(basename($file))."\" title=\""._FDDOWNLOADFILE.basename($file)."\">".basename($file)."</a>";
+				echo "<br />&nbsp;&nbsp;&nbsp;&#187;&nbsp;<a href=\"index.php?mod=".rawurlencodepath(eregi_replace("^sections/","",$dir))."#".rawurlencodepath(create_id($file))."\" title=\""._FDDOWNLOADFILE.basename($file)."\">".basename($file)."</a>";
 				if ((time()-getfiletime($file))<$newfiletime*3600) {
 					echo "&nbsp;<img src=\"images/mime/new.gif\" alt=\"new file!\">";
 				}
@@ -643,17 +660,17 @@ $myforum = get_username();
 
 global $bgcolor3,$bgcolor2,$icon_style,$extensions,$theme,$newfiletime,$archivedir;
 
-echo "<table bgcolor=\"$bgcolor3\" style=\"width:100%; border-collapse: collapse;border:1px solid $bgcolor2;\" border=\"1\" cellspacing=\"0\">";
-echo "<tr><td colspan=\"2\"><b>"._FDSUMMARY.":</b></td></tr>";
+echo "<table bgcolor=\"$bgcolor3\" style=\"width:100%; border-collapse: collapse;border:1px solid; border-color: $bgcolor2;\" border=\"1\" cellspacing=\"0\">";
+echo "<tr><td colspan=\"2\" style=\"border-color: $bgcolor2;\"><b>"._FDSUMMARY.":</b></td></tr>";
 echo "<tr>";
-echo "<td><b>Files:</b></td>";
-echo "<td><b>"._FDSUBDIRS.":</b></td>";
+echo "<td style=\"border-color: $bgcolor2;\"><b>Files:</b></td>";
+echo "<td style=\"border-color: $bgcolor2;\"><b>"._FDSUBDIRS.":</b></td>";
 echo "</tr>";
 
 $files = array();
 $files = list_fd_files("sections/$mod/");
 echo "<tr>";
-echo "<td style=\"width: 50%;vertical-align : top;\">";
+echo "<td style=\"width: 50%;vertical-align : top; border-color: $bgcolor2;\">";
 
 if (count($files)>0){
 	$file = "";
@@ -709,7 +726,7 @@ if (count($files)>0){
 echo "</td>";
 
 //inizio sezioni
-echo "<td style=\"width: 50%;vertical-align : top;\">";
+echo "<td style=\"width: 50%;vertical-align : top; border-color: $bgcolor2;\">";
 $dirstemp = array();
 $dirstemp = list_subdirs("sections/$mod/");
 $dirs = array();
