@@ -1,4 +1,10 @@
 <?
+
+if (eregi("ff_functions.php",$_SERVER['PHP_SELF'])) {
+    Header("Location: ../../index.php");
+    fd_die("You cannot call ff_functions.php!",__FILE,__LINE);
+}
+
 /**
  * Flatforum: un forum integrato nella struttura di Flatnuke
  * 
@@ -26,7 +32,7 @@ include_once("download/fd+.php");
  * Restituisce la root del forum
  * 
  * Questa funzione restituisce il percorso della cartella principale del forum attivo.
- * (cos diventa semplice definire dove deve trovarsi la root del forum)
+ * (cosi' diventa semplice definire dove deve trovarsi la root del forum)
  * 
  * @return string il path della root del forum.
  * @since 0.1
@@ -43,7 +49,7 @@ function get_forum_root(){
 			}
 			else echo "Non sono riuscito a creare la cartella <b>misc/flatforum</b>, verificare i permessi";
 		}
-		else echo "La cartella <b>misc</b> non  scrivibile, verificare i permessi!";
+		else echo "La cartella <b>misc</b> non e' scrivibile, verificare i permessi!";
 	}
 	return "misc/flatforum/";
 // 	$mod = getparam("mod",PAR_GET,SAN_FLAT);
@@ -155,7 +161,7 @@ function list_argument_topics($root,$group,$argument,$first_on_top="false",$show
 			foreach ($ntopics as $ntopic){
 				if (preg_match("/^top_/",basename($ntopic))) continue;
 
-				//verifico se  nascosto
+				//verifico se e' nascosto
 				$topicdata = array();
 // 				$topicdata = load_topic_properties($ntopic);
 				
@@ -202,7 +208,7 @@ function list_argument_topics($root,$group,$argument,$first_on_top="false",$show
 		$sortedtopics = array();
 		for ($count=0;$count<count($topics);$count++){
 			$topic = $topics[$count];
-			//controllo se  nascosto
+			//controllo se e' nascosto
 			$topicdata = array();
 // 			$topicdata = load_topic_properties($topic);
 			if ($show_hidden=="false" and preg_match("/^hide_/",basename($topic))) 
@@ -249,8 +255,8 @@ if (!check_path($root,get_forum_root(),"false")) ff_die("forum root is not valid
  * Struttura dell'array restituito:
  * $data['properties']['topictitle'] = il titolo del topic
  * $data['properties']['icon'] = l'icona associata al topic
- * $data['properties']['locked'] = indica se il topic  bloccato
- * $data['properties']['hide'] = indica se il topic  nascosto
+ * $data['properties']['locked'] = indica se il topic e' bloccato
+ * $data['properties']['hide'] = indica se il topic e' nascosto
  * $data['properties']['hits'] = indica il numero di letture del topic
  * $data['properties']['important'] = indica se il topic deve essere messo in rilievo
  * $data['properties']['postontop'] = indica se un post deve essere sempre visualizzato per primo
@@ -283,7 +289,7 @@ function load_topic($topicfile){
 	$string = get_file($topicfile);
 	
 	global $theme;
-	//CARICO LE PROPRIET DEL TOPIC
+	//CARICO LE PROPRIETA' DEL TOPIC
 	$properties = array();
 	$properties = ff_get_xml_element("ff:properties",$string);
 	
@@ -435,7 +441,7 @@ function fast_load_topic($topicfile){
 	$string = get_file($topicfile);
 	
 	global $theme;
-	//CARICO LE PROPRIET DEL TOPIC
+	//CARICO LE PROPRIETA' DEL TOPIC
 	$properties = array();
 	$properties = ff_get_xml_element("ff:properties",$string);
 	
@@ -517,13 +523,13 @@ function fast_load_topic($topicfile){
 }
 
 /**
- * Carica in un array multidimensionale il file xml con le propriet del topic
+ * Carica in un array multidimensionale il file xml con le proprieta' del topic
  * 
  * Struttura dell'array restituito:
  * $data['properties']['topictitle'] = il titolo del topic
  * $data['properties']['icon'] = l'icona associata al topic
- * $data['properties']['locked'] = indica se il topic  bloccato
- * $data['properties']['hide'] = indica se il topic  nascosto
+ * $data['properties']['locked'] = indica se il topic e' bloccato
+ * $data['properties']['hide'] = indica se il topic e' nascosto
  * $data['properties']['hits'] = indica il numero di letture del topic
  * $data['properties']['important'] = indica se il topic deve essere messo in rilievo
  * $data['properties']['postontop'] = indica se un post deve essere sempre visualizzato per primo
@@ -548,7 +554,7 @@ function load_topic_properties($topicfile){
 	$string = get_file($topicfile);
 	
 	global $theme;
-	//CARICO LE PROPRIET DEL TOPIC
+	//CARICO LE PROPRIETA' DEL TOPIC
 	$properties = array();
 	$properties = ff_get_xml_element("ff:properties",$string);
 	
@@ -791,11 +797,11 @@ function save_topic($topicfile,$data){
 		</ff:post>";
 	}
 	
-	//controllo se l'argomento  bloccato
+	//controllo se l'argomento e' bloccato
 	$dir ="";
 	$dir = dirname($topicfile);
 	if (file_exists("$dir/lock") and !is_admin() and !is_forum_moderator()){
-		echo "L'argomento  bloccato";
+		echo "L'argomento e' bloccato";
 		return;
 	}
 	//devo essere nella cartella di un argomento (deve esistere il file argument.php)
@@ -831,7 +837,7 @@ function ff_die($message="",$file="",$line=""){
 }
 
 /**
- * Carica le propriet dell'argomento specificato
+ * Carica le proprieta' dell'argomento specificato
  * 
  * $data['icon'] = l'icona associata all'argomento
  * $data['description'] = la descrizione dell'argomento
@@ -840,7 +846,7 @@ function ff_die($message="",$file="",$line=""){
  * 
  * @param string $root la root del forum
  * @param string $argument il nome dell'argomento
- * @return un array con le propriet
+ * @return un array con le proprieta'
  * @author Aldo Boccacci
  * @since 0.1
  */
@@ -897,9 +903,9 @@ function load_argument_props($root,$group,$argument){
 }
 
 /**
- * Salva le propriet dell'argomento
+ * Salva le proprieta' dell'argomento
  * 
- * Salva le propriet dell'argomento
+ * Salva le proprieta' dell'argomento
  * 
  * @param string $root la root del forum
  * @param string $argument il nome dell'argomento
@@ -966,12 +972,12 @@ function save_argument_props($root,$group,$argument,$data){
 }
 /**
  * L'interfaccia per operare sui post
- * Modalit consentite:
+ * Modalita' consentite:
  * - newtopic
  * - newpost
  * - editpost
  * 
- * @param string mode la modalit dell'interfaccia
+ * @param string mode la modalita' dell'interfaccia
  * @param string $file il file contenente i dati del topic
  * @author Aldo Boccacci
  * @since 0.1
@@ -1249,7 +1255,7 @@ function update_topic_hits($topicfile){
 
 
 /**
- * Restituisce TRUE se il topic specificato non  nascosto.
+ * Restituisce TRUE se il topic specificato non e' nascosto.
  * 
  * @param string $topicfile il file contenente il topic
  * @since 0.1
@@ -1267,7 +1273,7 @@ function topic_is_visible($topicfile){
 }
 
 /**
- * Restituisce TRUE se il topic specificato non  nascosto.
+ * Restituisce TRUE se il topic specificato non e' nascosto.
  * 
  * @param string $topicfile il file contenente il topic
  * @since 0.1
@@ -1276,7 +1282,7 @@ function topic_is_visible($topicfile){
 function topic_is_locked($topicfile){
 	if (!check_path($topicfile,"","true")) ff_die("\$topicfile is not valid!(".strip_tags($topicfile).")",__FILE__,__LINE__);
 	
-	//prima controllo se  bloccato l'argomento
+	//prima controllo se e' bloccato l'argomento
 	$tmp = dirname($topicfile);
 	$argument = basename($tmp);
 	$tmp = dirname($tmp);
@@ -1414,7 +1420,7 @@ function add_post(){
 	if (file_exists($topicfile))
 	$data = load_topic($topicfile);
 	
-	//se  bloccato
+	//se e' bloccato
 	if (!is_forum_moderator() and topic_is_locked($topicfile))
 		ff_die("Only admins and forum moderators can add posts to locked topics!");
 	
@@ -1444,7 +1450,7 @@ function add_post(){
 	//avvisa gli utenti del nuovo post
 	email_alert($group,$argument,$topic);
 	
-	//aggiorno le statistiche dell'argomento (se il topic non  nascosto!)
+	//aggiorno le statistiche dell'argomento (se il topic non e' nascosto!)
 	if (topic_is_visible($topicfile)){
 		$argumentstats = load_argument_stats($group,$argument);
 		$argumentstats['posts'] = ($argumentstats['posts']+1);
@@ -1533,7 +1539,7 @@ function edit_post(){
 	if (file_exists($topicfile))
 	$data = load_topic($topicfile);
 	
-	//se  bloccato
+	//se e' bloccato
 	if (!is_forum_moderator() and topic_is_locked($topicfile))
 		ff_die("Only admins and forum moderators can edit locked posts!");
 	if (!is_admin() and (trim($data['posts'][$post]['poster'])!=get_username()) and !is_forum_moderator()) ff_die("Only admins and owners can edit posts!",__FILE__,__LINE__);
@@ -1566,7 +1572,7 @@ function edit_post(){
 }
 
 /**
- * Restituisce true se l'utente collegato pu vedere l'argomento
+ * Restituisce true se l'utente collegato puo' vedere l'argomento
  * 
  * @param string $root la root del forum
  * @param string $group il gruppo di riferimento
@@ -1679,7 +1685,7 @@ function alert_list_remove(){
 		fflogf("topic file doesn't exists! (".strip_tags($topicfile).")","ERROR");
 	}
 	
-	echo "<div align=\"center\">In caso di nuovi messaggi in questa discussione non sarai pi avvisato con una e-mail.</div>";
+	echo "<div align=\"center\">In caso di nuovi messaggi in questa discussione non sarai piu' avvisato con una e-mail.</div>";
 	echo "<meta http-equiv=\"Refresh\" content=\"1; URL=index.php?mod=".rawurlencodepath($mod)."&amp;group=".rawurlencodepath($group)."&amp;argument=".rawurlencodepath($argument)."&amp;topic=$topic\" >";
 	
 }
@@ -1740,34 +1746,30 @@ function email_alert($group,$argument,$topic){
 			
 			if (!isset($userprofile['mail'])) continue;
 			
-			//controllo la validit della mail
+			//controllo la validita' della mail
 			if (!check_mail($userprofile['mail'])) continue;
 			
 			//url
 			$url = "http://".$_SERVER['SERVER_NAME']."/".$_SERVER['SCRIPT_NAME']."?mod=$mod&group=$group&argument=$argument&topic=$topic";
 			
 			global $sitename;
-			
-			
-			
-			$message= "";
-			$message=" arrivato un nuovo messaggio nel topic \"".$topicdata['properties']['topictitle']."\":\n$url\n\nAutore: ".get_username();
-			
+
+			$message="E' arrivato un nuovo messaggio nel topic \"".$topicdata['properties']['topictitle']."\":\n$url\n\nAutore: ".get_username();
 			
 // 			echo "MAIL SPEDITA:<br/>$message";
-			mail($userprofile['mail'],"Arrivato un nuovo messaggio su $sitename", $message,"FROM: $sitename <noreply@noreply>\n");
+			mail($userprofile['mail'],"Arrivato un nuovo messaggio su $sitename", $message,"FROM: $sitename <noreply@noreply>\r\nX-Mailer: Flatnuke on PHP/".phpversion());
 		}
 	}
 
 }
 
 /**
- * Restituisce TRUE se l'argomento  bloccato, FALSE in caso contrario.
+ * Restituisce TRUE se l'argomento e' bloccato, FALSE in caso contrario.
  * 
  * @param string $root la root del forum
  * @param string $group il gruppo di riferimento
  * @param string $argument l'argomento di riferimento
- * @return TRUE se l'argomento  bloccato, FALSE in caso contrario
+ * @return TRUE se l'argomento e' bloccato, FALSE in caso contrario
  * @author Aldo Boccacci
  * @since 0.1
  */
@@ -1891,7 +1893,7 @@ function ff_is_spam($string,$spamfile){
  * Salva le statistiche dell'argomento indicato, in modo da visualizzarle velocemente in fase di lettura
  * @param string $group il gruppo di riferimento
  * @param string $argument l'argomento di riferimento
- * @return TRUE se l'argomento  bloccato, FALSE in caso contrario
+ * @return TRUE se l'argomento e' bloccato, FALSE in caso contrario
  * @author Aldo Boccacci
  * @since 0.1
  */
@@ -1945,7 +1947,7 @@ function save_argument_stats($group,$argument,$data){
  * Carica le statistiche dell'argomento indicato, in modo da visualizzarle velocemente in fase di lettura
  * @param string $group il gruppo di riferimento
  * @param string $argument l'argomento di riferimento
- * @return TRUE se l'argomento  bloccato, FALSE in caso contrario
+ * @return TRUE se l'argomento e' bloccato, FALSE in caso contrario
  * @author Aldo Boccacci
  * @since 0.1
  */
@@ -2273,7 +2275,7 @@ function ff_get_xml_element($elem, $xml) {
  * Il messaggio viene formattato aggiungendo campi di interesse.
  * 
  * @param string $message il messaggio da salvare
- * @param string $type il tipo di messaggio. Pu essere lasciato vuoto o 
+ * @param string $type il tipo di messaggio. Puo' essere lasciato vuoto o 
  *               impostato a "ERROR"
  * @author Aldo Boccacci
  * @since 0.1
