@@ -1,4 +1,10 @@
 <?
+
+if (eregi("ffadmin.php",$_SERVER['PHP_SELF'])) {
+    Header("Location: ../../index.php");
+    fd_die("You cannot call ffadmin.php!",__FILE,__LINE);
+}
+
 /**
  * Flatforum: un forum integrato nella struttura di Flatnuke
  * 
@@ -283,7 +289,9 @@ function evidenzia_topic($group,$argument,$topic,$evidenzia){
 	}
 	
 	update_topics_list($group,$argument);
-	
+	update_argument_stats($group,$argument);
+	echo "<div align=\"center\"><a href=\"index.php?mod=".rawurlencodepath($mod)."&amp;group=".rawurlencodepath($group)."&amp;argument=".rawurlencodepath($argument)."\" >"._RETURN."</a>
+	</div>";
 	echo "<meta http-equiv=\"Refresh\" content=\"1; URL=index.php?mod=".rawurlencodepath($mod)."&amp;group=".rawurlencodepath($group)."&amp;argument=".rawurlencodepath($argument)."\" >";
 // 	header("index.php?mod=".rawurlencodepath($mod)."&amp;group=".rawurlencodepath($group)."&amp;argument=".rawurlencodepath($argument));
 }
