@@ -1,4 +1,9 @@
 <?
+if (eregi("ffview.php",$_SERVER['PHP_SELF'])) {
+    Header("Location: ../../index.php");
+    fd_die("You cannot call ffview.php!",__FILE,__LINE);
+}
+
 /**
  * Flatforum: un forum integrato nella struttura di Flatnuke
  * 
@@ -58,7 +63,7 @@ if (!is_writable(get_forum_root())) echo _THEDIR." <b>".get_forum_root()."</b> "
 
 if (count(list_forum_groups(get_forum_root()))==0) echo "disabled=\"disabled\"";
 ?> />
-<?if (count(list_forum_groups(get_forum_root()))==0) echo "<br /><i>Devi prima creare uno o pi gruppi</i>";?>
+<?if (count(list_forum_groups(get_forum_root()))==0) echo "<br /><i>Devi prima creare uno o piu' gruppi</i>";?>
 </form>
 </div>
 <?
@@ -252,11 +257,11 @@ function forum_view_argument($root,$group,$argument){
 		if (topic_is_locked($topic)) echo "<br/><img src=\"forum/icons/lock.png\" alt=\"Lock\" />";
 		echo "</td>";
 		echo "<td class=\"forum-arg-mess\" align=\"left\">";
-		//se  nascosto
+		//se e' nascosto
 		if (is_forum_moderator() and !topic_is_visible($topic))
 			echo "<span style=\"color : #ff0000; text-decoration : line-through;\">";
 		echo "<a href=\"index.php?mod=".rawurlencodepath($mod)."&amp;group=".rawurlencodepath($group)."&amp;argument=".rawurlencodepath($argument)."&amp;topic=".basename($topic)."&amp;page=last\" title=\""._VIEWTOPICTITLE.": ".$topicdata['properties']['topictitle']."\">".$topicdata['properties']['topictitle']."</a>";
-		//se  nascosto
+		//se e' nascosto
 		if (is_forum_moderator() and !topic_is_visible($topic))
 			echo "</span>";
 		echo "</td>";
@@ -342,7 +347,7 @@ function forum_view_argument($root,$group,$argument){
 				}
 				
 				//LOCKING
-				//se  bloccato l'argomento non posso agire sul singolo topic
+				//se e' bloccato l'argomento non posso agire sul singolo topic
 				if (!argument_is_locked(get_forum_root(),$group,$argument)){
 					if (topic_is_locked($topic)){
 						echo " | <img src=\"forum/icons/unlock.png\" alt=\"Unlock\" />&nbsp;";
@@ -400,7 +405,7 @@ function forum_view_argument($root,$group,$argument){
 	echo "</td></tr></table>";
 	
 	if (count($topics)>$topicperpage){
-		//Per accessibilit
+		//Per accessibilita'
 		echo "<div style=\"text-align: center;\"><noscript><br /><br />";
 
 		for ($count=1; $count<$pagescount+1;$count++){
@@ -454,7 +459,7 @@ function ff_view_group($root,$group){
 	else echo " style=\"font-size: 140%; font-weight : bolder;\" ";
 	
 	$groupname= "";
-	$groupname = str_replace("_"," ",eregi_replace("^[0-9][0-9]_","",$group));
+	$groupname = str_replace("_"," ",eregi_replace("^[0-9]*_","",$group));
 	
 	echo " href=\"index.php?mod=$mod&amp;group=$group\" title=\""._VIEWGROUPTITLE.": $groupname\">$groupname</a></span>";
 	
@@ -495,7 +500,7 @@ function ff_view_group($root,$group){
 		$argumentstats = load_argument_stats($group,$argument);
 		
 		$argumentname="";
-		$argumentname= str_replace("_"," ",eregi_replace("^[0-9][0-9]_","",$argument));
+		$argumentname= str_replace("_"," ",eregi_replace("^[0-9]*_","",$argument));
 		
 		echo "<tr>";
 		echo "<td class=\"forum-group-icon\" align=\"right\" valign=\"top\"><img src=\"".$argumentdata['icon']."\" alt=\"icon\" />";
@@ -584,7 +589,7 @@ function forum_view_topic($root,$group,$argument,$topic){
 	if (!check_path($topicpath,"","true")) ff_die("forum topicpath is not valid!",__FILE__,__LINE__);
 	
 	if (!is_file($topicpath)) {
-		echo "Il percorso richiesto non  un file: ".strip_tags($topicpath);
+		echo "Il percorso richiesto non e' un file: ".strip_tags($topicpath);
 	}
 	
 	$page = getparam("page",PAR_GET,SAN_FLAT);
@@ -683,7 +688,7 @@ function forum_view_topic($root,$group,$argument,$topic){
 	for ($count;$count <($postperpage+$oldcount); $count++){
 		if (isset($posts[$count])) $post = $posts[$count];
 		else continue;
-		//mostro il post (a meno che non lo abbia gi mostrato in cima)
+		//mostro il post (a meno che non lo abbia gia' mostrato in cima)
 		if ($postontop==$count) {
 			if ($postontop!="") continue;
 		}	
@@ -727,7 +732,7 @@ function forum_view_topic($root,$group,$argument,$topic){
 			<input type=\"hidden\" name=\"ffargument\" readonly=\"readonly\" value=\"$argument\" />
 			<input type=\"hidden\" name=\"fftopic\" readonly=\"readonly\" value=\"$topic\" />";
 		
-		//se  non in lista gli permetto di aggiungersi
+		//se e' non in lista gli permetto di aggiungersi
 		if (!in_array(get_username(), $topicdata['properties']['emailalert'])){
 			
 			echo "<input type=\"hidden\" name=\"ffaction\" readonly=\"readonly\" value=\"alertuser\" />";
@@ -842,7 +847,23 @@ function forum_view_user_profile($user){
 	if (trim($userdata['homepage'])!=""){
 		echo "<a href=\"".$userdata['homepage']."\" target=blank title=\"home page dell'utente\"><img src=\"forum/icons/home.png\" alt=\"home page\" border=0 /></a>";
 	}
-	
+
+	echo "<div style='align:center;border:0;'>\n";
+	if (trim($userdata['jabber'])!=""){
+		?><a href="xmpp:<?=$userdata['jabber']?>"><img src="images/useronline/im_jabber.png" alt="Jabber" title="Jabber" border="0" /></a><?
+	}
+	if (trim($userdata['skype'])!=""){
+		?>
+		<script type="text/javascript" src="http://download.skype.com/share/skypebuttons/js/skypeCheck.js"></script>
+		<a href="skype:<?=$userdata['skype']?>?chat" onclick="return skypeCheck();"><img src="http://mystatus.skype.com/smallicon/<?=$userdata['skype']?>" alt="Skype" title="Skype" border="0" /></a><?
+	}
+	if (trim($userdata['icq'])!=""){
+		?>&nbsp;<a href="http://people.icq.com/people/cmd.php?uin=<?=$userdata['icq']?>&amp;action=message"><img src="http://status.icq.com/online.gif?icq=<?=$userdata['icq']?>&amp;img=26" alt="ICQ" title="ICQ" border="0" /></a><?
+	}
+	if (trim($userdata['msn'])!=""){
+		?>&nbsp;<a href="msnim:chat?contact=<?=$userdata['msn']?>"><img src="images/useronline/im_msn.png" alt="MSN" title="MSN" border="0" /></a><?
+	}
+	echo "\n</div>\n";
 }
 /**
  * Mostra l'intestazione del forum con le opzioni generali.
@@ -905,7 +926,7 @@ function view_forum_header(){
 			$plugin_name ="";
 			$plugin_name = eregi_replace("\.php$","",basename($plugin));
 			if (eregi("^none_",$plugin_name)) continue;
-			echo "<option value=\"$plugin_name\">".eregi_replace("^[0-9][0-9]_","",$plugin_name)."</option>\n";
+			echo "<option value=\"$plugin_name\">".eregi_replace("^[0-9]*_","",$plugin_name)."</option>\n";
 	
 		}
 	?>
@@ -994,13 +1015,13 @@ function view_forum_header(){
 	$topicdata = load_topic(get_forum_root()."/$group/$argument/$topic");
 	
 	echo "<b><br/>Navigazione:</b><br/>";
-	echo "[ <a href=\"index.php?mod=".rawurlencodepath($mod)."\" title=\""._VIEWFORUMHOME."\"><b>".eregi_replace("^[0-9][0-9]_","",basename($mod))."</b></a>";
+	echo "[ <a href=\"index.php?mod=".rawurlencodepath($mod)."\" title=\""._VIEWFORUMHOME."\"><b>".eregi_replace("^[0-9]*_","",basename($mod))."</b></a>";
 	if ($group!="")
-		echo " / <a href=\"index.php?mod=".rawurlencodepath($mod)."&amp;group=".rawurlencodepath($group)."\" title=\""._VIEWGROUPTITLE.": ".str_replace("_"," ",eregi_replace("^[0-9][0-9]_","",$group))."\"><b>".str_replace("_"," ",eregi_replace("^[0-9][0-9]_","",$group))."</b></a> ";
+		echo " / <a href=\"index.php?mod=".rawurlencodepath($mod)."&amp;group=".rawurlencodepath($group)."\" title=\""._VIEWGROUPTITLE.": ".str_replace("_"," ",eregi_replace("^[0-9]*_","",$group))."\"><b>".str_replace("_"," ",eregi_replace("^[0-9]*_","",$group))."</b></a> ";
 	if ($argument!="" and $group!=""){
 		if ($topic!="")
-			echo "/ <a href=\"index.php?mod=".rawurlencodepath($mod)."&amp;group=".rawurlencodepath($group)."&amp;argument=".rawurlencodepath($argument)."\" title=\""._VIEWARGUMENTTITLE.": ".str_replace("_"," ",eregi_replace("^[0-9][0-9]_","",$argument))."\"><b>".str_replace("_"," ",eregi_replace("^[0-9][0-9]_","",$argument))."</b></a>";
-		else echo "/ ".str_replace("_"," ",eregi_replace("^[0-9][0-9]_","",$argument));
+			echo "/ <a href=\"index.php?mod=".rawurlencodepath($mod)."&amp;group=".rawurlencodepath($group)."&amp;argument=".rawurlencodepath($argument)."\" title=\""._VIEWARGUMENTTITLE.": ".str_replace("_"," ",eregi_replace("^[0-9]*_","",$argument))."\"><b>".str_replace("_"," ",eregi_replace("^[0-9]*_","",$argument))."</b></a>";
+		else echo "/ ".str_replace("_"," ",eregi_replace("^[0-9]*_","",$argument));
 	}
 	
 	if ($group!="" and $argument!="" and $topic!="")
@@ -1108,7 +1129,7 @@ function view_post($post,$topicdata,$group,$argument,$topic,$count){
 }
 
 /**
- * se  presente il file get_forum_root()/ffmotd.php
+ * se e' presente il file get_forum_root()/ffmotd.php
  * visualizza il testo contenuto nella pagina di riepilogo generale del forum
  */
 function view_ffmotd(){
@@ -1150,7 +1171,7 @@ if (!check_path($root,get_forum_root(),"false")) ff_die("forum root is not valid
 	if (!check_path($topicpath,"","true")) ff_die("forum topicpath is not valid!",__FILE__,__LINE__);
 	
 	if (!is_file($topicpath)) {
-		echo "Il percorso richiesto non  un file: ".strip_tags($topicpath);
+		echo "Il percorso richiesto non e' un file: ".strip_tags($topicpath);
 	}
 	
 	$page = getparam("page",PAR_GET,SAN_FLAT);
