@@ -71,22 +71,22 @@ if(!function_exists("ImageJpeg")) {
 	//return; // se le librerie non sono installate, al posto della miniatura sara' visualizzata l'immagine originale rimpicciolita
 } else $gd_flag = TRUE;
 
-// controlla esistenza directory con file di configurazione in /misc, se non c' la crea
+// controlla esistenza directory con file di configurazione in /misc, se non c'e' la crea
 if(!file_exists($gallerycfgdir)) {
 	mkdir($gallerycfgdir, 0777);
 }
 
-// controlla esistenza file di configurazione in /misc/gallery, se non c' lo crea
+// controlla esistenza file di configurazione in /misc/gallery, se non c'e' lo crea
 if(!file_exists($galleryconf)) {
 	fnwrite($galleryconf, "<?xml version='1.0'?>\n<fig:columns>2</fig:columns>\n<fig:rows>3</fig:rows>\n<fig:dim-thumbs>175</fig:dim-thumbs>\n<fig:commenti>N</fig:commenti>\n<fig:reg-uploads>N</fig:reg-uploads>\n", "w+", array("nonull"));
 }
 
-// controlla esistenza file commenti in /misc/gallery, se non c' lo crea
+// controlla esistenza file commenti in /misc/gallery, se non c'e' lo crea
 if(!file_exists($gallerycomm)) {
 	fnwrite($gallerycomm, "<?xml version='1.0'?>\n", "w+", array("nonull"));
 }
 
-// controlla esistenza feed rss, se non c' lo crea
+// controlla esistenza feed rss, se non c'e' lo crea
 if(!file_exists($galleryfeed)) {
 	generate_Gallery_RSS($mod);
 }
@@ -183,7 +183,7 @@ if (($action != "") AND is_admin()) {
 	elseif($action=="delete") {
 		$file_del=getparam("file_del",PAR_POST,SAN_FLAT);
 		if($file_del=="" OR !eregi("(jpg|jpeg|png|gif)",get_file_extension($file_del))) {
-			// nessuna scelta effettuata o non  immagine, non faccio nulla :)
+			// nessuna scelta effettuata o non e' immagine, non faccio nulla :)
 		} elseif(unlink($file_del)) {
 			?><script language="javascript">alert('<?=_FIG_ALERTIMGDEL?>');</script><?
 		} else {
@@ -225,7 +225,7 @@ elseif(isset($_POST['writecomm'])) {
 	// si tratta del primo commento inserito
 	if(!stristr($string, "<fig:comments>"))
 		$string = "<?xml version='1.0'?>\n<fig:comments>\n\t<fig:comment>\n\t\t<fig:by>$by</fig:by>\n\t\t<fig:what>$what</fig:what>\n\t</fig:comment>\n</fig:comments>\n";
-	// c' almeno un commento gi inserito
+	// c'e' almeno un commento gia' inserito
 	else $string = str_replace("</fig:comments>", "\t<fig:comment>\n\t\t<fig:by>$by</fig:by>\n\t\t<fig:what>$what</fig:what>\n\t</fig:comment>\n</fig:comments>",$string);
 
 	fnwrite($gallerycomm, stripslashes("$string"), "w", array("nonull"));
@@ -255,7 +255,7 @@ if($n_file!=0) {
 // visualizzazione maschera per inserimento commenti
 if (getparam("inscomm", PAR_GET, SAN_FLAT) !="") {
 	OpenTableTitle(_FIG_ADDCOMM);
-	if($myforum!="" OR $guestcomment==1) {			// controllo se utente non registrato pu postare o no
+	if($myforum!="" OR $guestcomment==1) {			// controllo se utente non registrato puo' postare o no
 		if($myforum=="")
 			$by = _FIG_SCON;					// utente sconosciuto
 		else $by = $myforum;				// utente registrato
@@ -408,7 +408,7 @@ menu_change_page("toppage", $n_file, $rows, $cols, $pag);
 		if($i%$cols == 1)				// apertura nuova riga
 			echo "<tr bgcolor=\"$bgcolor3\">";
 		$nomefile = $array_dir[$i-1];
-		$nomefile = eregi_replace("^[0-9][0-9]_","",$nomefile); 	// elimina i numeri iniziali
+		$nomefile = eregi_replace("^[0-9]*_","",$nomefile); 	// elimina i numeri iniziali
 		$nomefile = eregi_replace("_"," ",$nomefile); 			// converte _ in spazi
 		$nomefile = eregi_replace("[\.]*[a-z0-9]{1,4}$","",$nomefile); 	// elimina l'estensione
 		$size = getimagesize($path."/".$array_dir[$i-1]);
@@ -553,7 +553,7 @@ function fig_upload($path) {
 		case("upload"):
 			if(is_admin()) {
 				if($_FILES['file_up']['name']<>"" AND eregi("(jpg|jpeg|png|gif)",get_file_extension($_FILES['file_up']['name']))) {
-					//controllo che il file non sia gi esistente
+					//controllo che il file non sia gia' esistente
 					if(file_exists("$path/".$_FILES['file_up']['name'])) {
 						?><script language="javascript">alert('<?=_FIG_ALERTEXIST?>');</script><?
 						return;
@@ -575,7 +575,7 @@ function fig_upload($path) {
 				if($_FILES['file_up']['name']<>"" AND eregi("(jpg|jpeg|png|gif)",get_file_extension($_FILES['file_up']['name']))) {
 					$new_file = explode(".",basename($_FILES['file_up']['name']));
 					$n = count($new_file) - 1;
-					//controllo che il file non sia gi esistente
+					//controllo che il file non sia gia' esistente
 					if(file_exists("$path/$new_file[0]_by_$myforum.$new_file[$n]")) {
 						?><script language="javascript">alert('<?=_FIG_ALERTEXIST?>');</script><?
 						return;
@@ -640,7 +640,7 @@ function generate_Gallery_RSS($sectionName) {
 		$filename = $gallery_dir."/".rawurlencode($modlist[$i]['name']);
 		$link = $url.$filename;
 		$mytitle = $modlist[$i]['name'];
-		$mytitle = eregi_replace("^[0-9][0-9]_","",$mytitle); 	// elimina i numeri iniziali
+		$mytitle = eregi_replace("^[0-9]*_","",$mytitle); 	// elimina i numeri iniziali
 		$mytitle = eregi_replace("_"," ",$mytitle); 			// converte _ in spazi
 		$mytitle = eregi_replace("[\.]*[a-z0-9]{1,4}$","",$mytitle); 	// elimina l'estensione
 		$body .= "\t\t<item>\n";
