@@ -51,10 +51,12 @@ if(defined('_THEME_DOCTYPE')) {
 	$doctype = _THEME_DOCTYPE;
 } else $doctype = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\">\n";	// default HTML 4.01 doctype
 // define close tag for XHTML doctype
+$namespace = "";
 if(ereg("DTD HTML", $doctype)) {
 	$close_tag = "";
 } elseif(ereg("DTD XHTML", $doctype)) {
 	$close_tag = " /";
+        $namespace = "xmlns=\"http://www.w3.org/1999/xhtml\"";
 }
 
 // dynamically build page's title and meta tags
@@ -68,20 +70,33 @@ if(trim($mod)!="") {
 	// build title
 	if(($mod=="read" OR $mod=="comment") AND file_exists(get_fn_dir('news')."/$id.xml")) {	// u're reading a news
 		$news  = get_file(get_fn_dir('news')."/$id.xml");
-		$page_title = get_xml_element("fn:title",$news);
+		$page_title      = get_xml_element("fn:title",$news);
+		$keywords        = eregi_replace('[\.]*[[:alpha:]]+$','',get_xml_element("fn:avatar",$news)).", $keywords";
+		$sitedescription = substr(strip_tags(get_xml_element("fn:header",$news)), 0, 200);
+		switch($mod) {
+			case "read":
+				$page_title      = _FLEGGI." &#58; $page_title";
+				$sitedescription = _FLEGGI." &#58; $sitedescription";
+			break;
+			case "comment":
+				$page_title      = _COMMENTI." &#58; $page_title";
+				$sitedescription = _COMMENTI." &#58; $sitedescription";
+			break;
+		}
 	} else {	// u're visiting a section
 		$page_title = str_replace("/", " - ", $mod);
 		$page_title = str_replace("none_", "", $page_title);
-		$page_title = eregi_replace("^[0-9][0-9]_", "", $page_title);
+		$page_title = eregi_replace("^[0-9]*_", "", $page_title);
+		$page_title = eregi_replace(" - [0-9]*_", " - ", $page_title);
 		$page_title = str_replace("_", " ", $page_title);
 	}
 	$title = "$sitename &raquo; $page_title";
 } else $title = $sitename;
 
 echo $doctype;
-echo "<html lang=\"$lang\">\n";
+echo "<html lang=\"$lang\" $namespace>\n";
 echo "<head>\n";
-echo "<title>$title</title>\n";
+echo "<title>".stripslashes($title)."</title>\n";
 echo "<meta http-equiv=\"content-type\" content=\"text/html; charset="._CHARSET."\"$close_tag>\n";
 echo "<meta http-equiv=\"expires\" content=\"0\"$close_tag>\n";
 echo "<meta name=\"resource-type\" content=\"document\"$close_tag>\n";
@@ -214,6 +229,8 @@ if(file_exists($path_js)) {
 		}
 	}
 	closedir($dir_js);
+	if(count($array_js)>0)
+		sort($array_js);
 	for($i=0; $i<$file_js; $i++) {
 		echo "\n<script type='text/javascript' src='$path_js/$array_js[$i]'></script>";
 	}
