@@ -1,6 +1,6 @@
 <? die(); ?>
-# il segno di cancelletto all'inizio della linea indica i commenti
-# ogni linea  un'espressione regolare che identifica un termine ritenuto spam
+# il segno di cancelletto all'inizio della linea indica i commenti;
+# ogni linea e' un'espressione regolare che identifica un termine ritenuto spam.
 phentermine
 dospan
 roulette
@@ -30,16 +30,16 @@ aput
 apyrin
 arcjet
 arctg
-myboard\.info
 byplay
 5000megs
 sex
 lesbo
+lesbian
 gay
 janecelka
+bondage
 
 #sites
-\+\+\+\+\+
 bombets\.org
 bombey7\.org
 volimar\.org
@@ -49,6 +49,8 @@ bolshenepiy\.org
 valtbess\.org
 pij0n\.org
 kolomrt\.org
+myboard\.info
 
 #html
-(a)\s+(href)
\ No newline at end of file
+(a)\s*(href)
+(<\s*\/\s*a\s*>)
\ No newline at end of file
