@@ -7,7 +7,7 @@ if (eregi("print_subsections.php",$_SERVER['PHP_SELF'])) {
    
 $sections_path = get_fn_dir("sections");
 $mod = getparam("mod", PAR_GET, SAN_FLAT);
-if (!file_exists("$sections_path/$mod/forum") AND !file_exists("$sections_path/$mod/download")) {
+if ($mod!="" AND !file_exists("$sections_path/$mod/forum") AND !file_exists("$sections_path/$mod/download")) {
 	print_subsections($mod);
 }
 
