@@ -426,4 +426,41 @@ define("_CHANGESECTTYPE","Change section type");
 define("_EXEC","Exec");//check translation
 define("_CHOOSEACTION","Choose action");
 define("_MANAGESECTNOTE","Edit section's text or choose an admin option on the right");
+define("_FNPRESENTATION","Presentation");//check translation
+
+// 2.7.1
+define("_NEWPWDSTRING","Lost password");
+define("_NEWPWDFORM","<b>Recover Password</b>:<br /><br />
+	To recover your password, please provide the e-mail address you have
+	associated with your member account and click on the Submit button.<br />
+	The e-mail will also contain your NEW password.<br />
+	Pay attention on the fact that you will not be able to use your new password
+	till you will validate the request; so, without validation,
+	you still have to use the old password.");
+define("_NEWPWDFROM","Recover password from:");
+define("_NEWPWDMAIL","Hi __USERNAME__,\n
+this email has been sent to you from __SITEURL__ because someone asked to
+provide a new password for your account.\n
+If you didn't request anything, just ignore this email: your password
+will remain the same. To avoid errors or abuses, only you are able
+to validate password recovery.\n
+*** Continue only if you want to recover your password ***\n
+------------------------------------------------
+HOW TO VALIDATE THE REQUEST
+------------------------------------------------\n
+To validate your request, just click on link below:\n
+__URLCONFIRMPASSWORDCHANGE__\n
+(your e-mail program should open the download page in your browser;
+if your e-mail program does not do this, you can paste the URL in your browser
+and press the Enter key to open the link).\n
+Once this process of activation/validation will be completed,
+you can login to the site using the new password you can find below.
+You can change your password at any time by editing your account information.\n
+------------------------------------------------
+YOUR NEW PASSWORD (AFTER VALIDATION)
+------------------------------------------------\n
+Use your new password only after visiting the link in this e-mail.\n
+After validation, your new password will be: __REGCODE__\n
+Keep your password secure and do not share it with other people.
+You can change your password at any time by editing your account information.");
 ?>
\ No newline at end of file
