@@ -154,7 +154,7 @@ define("_NOPUBNEWS","Non ci sono notizie segnalate");
 define("_MOTDMESS","Benvenuti su <b>Flatnuke</b><br /><br /><b>Flatnuke</b>  un CMS (Content Management System) che non fa uso di
 DBMS, appoggiandosi esclusivamente a file di testo (da qui il nome).<br />L'home page di <b>Flatnuke</b> 
 <a href=\"http://www.flatnuke.org/\">questa</a>.<br /><br /><b>ATTENZIONE! </b><br />Per amministrare il sito occorre creare un account,
-<b>il primo utente che si registra sar amministratore</b> (avr tutti i permessi)! &gt;&gt;<a href=\"index.php?mod=none_Login&action=visreg\">CREALO ORA!</a>
+<b>il primo utente che si registra sar amministratore</b> (avr tutti i permessi)! &gt;&gt;<a href=\"index.php?mod=none_Login&amp;action=visreg\">CREALO ORA!</a>
 &lt;&lt;<br /><br />Se hai apprezzato Flatnuke <b>mandami una cartolina</b> dalla tua citt! Trovi il mio indirizzo sul file AUTHOR");
 define("_LEVEL","Livello");
 define("_NOLEVELSECT","Non hai i permessi per visualizzare questa sezione");
