@@ -29,7 +29,7 @@ $month = getparam("month",PAR_GET,SAN_HTML);
 $modname = getparam("mod", PAR_GET, SAN_FLAT);
 if($year=="" AND $month==""){
 	$my_modlist = "";
-	$handle=opendir('news');
+	$handle=opendir(get_fn_dir('news'));
 	while ($file = readdir($handle)) {
 		if (!( $file=="." or $file==".." )) {
 		$my_modlist .= "$file ";
@@ -47,6 +47,7 @@ if($year=="" AND $month==""){
 		}
 	}
 	echo "<ul>";
+	if(count($okanno)>0) sort($okanno);
 	for ($i=0; $i < count($okanno); $i++){
 		if($okanno[$i]!="")
 			echo "<li><a href=\"index.php?mod=".$modname."&amp;year=".($okanno[$i])."\">$okanno[$i]</a></li>";
@@ -78,7 +79,7 @@ if($year=="" AND $month==""){
 	echo "<div style=\"clear:both\"></div>";
 } else if($year!="" AND $month==""){
 	$my_modlist = "";
-	$handle=opendir('news');
+	$handle=opendir(get_fn_dir('news'));
 	while ($file = readdir($handle)) {
 		if (!( $file=="." or $file==".." )) {
 			$my_modlist .= "$file ";
@@ -107,7 +108,7 @@ if($year=="" AND $month==""){
 	echo "<a href=\"javascript:history.back();\">&lt;&lt; "._INDIETRO."</a>";
 } else {
 	$my_modlist = "";
-	$handle=opendir('news');
+	$handle=opendir(get_fn_dir('news'));
 	while ($file = readdir($handle)) {
 		if (!( $file=="." or $file==".." )) {
 			$my_modlist .= "$file ";
