@@ -3,7 +3,7 @@
  * Print main menu with options' icons
  *
  * @author Marco Segato <segatom@users.sourceforge.net>
- * @version 20070729
+ * @version 20080607
  */
 function fncc_main() {
 	// security conversions
@@ -61,6 +61,12 @@ function fncc_main() {
 			<img src="<?=get_fn_dir("sections")?>/<?=$mod?>/none_images/poll.png" alt="poll" border="0" /><br /><?=_FNCC_POLL?>
 		</a>
 	</div>
+	<!-- DOWNLOAD CONFIGURATION -->
+	<div style="<?=$div_option_style?>">
+		<?= build_ahah_link($mod, "&amp;op=fnccdownconf", "fn_adminpanel", "get"); ?>
+			<img src="<?=get_fn_dir("sections")?>/<?=$mod?>/none_images/down.png" alt="download" border="0" /><br /><?=_FNCC_DOWNCONF?>
+		</a>
+	</div>
 	</div>
 	<!-- HEADER -->
 	<div style="<?=$div_header_style?>">&nbsp;&#8226;&nbsp;<?=_FNCC_USERS?></div>
@@ -379,6 +385,29 @@ function fncc_polledit() {
 	echo _FNCC_HEADERBACK;
 }
 
+/*
+ * Manage FdPlus configuration
+ *
+ * @author Marco Segato <segatom@users.sourceforge.net>
+ * @version 20080607
+ */
+function fncc_downconf() {
+	// security conversions
+	$mod = getparam("mod", PAR_GET, SAN_FLAT);
+	// print the back button
+	echo _FNCC_HEADERBACK;
+	// print html code
+	?><div style="text-align: center;">
+		<img src="<?=get_fn_dir("sections")?>/<?=$mod?>/none_images/down.png" alt="download" border="0" />
+	</div>
+	<div style="padding: 2em 0.5em 2em 0.5em;">
+		<center><h4><?=_FNCC_DESDOWNCONF?></h4></center>
+		<div style="padding-top:1em;"><? fncc_fdplusconf(); ?></div>
+	</div><?
+	// print the back button
+	echo _FNCC_HEADERBACK;
+}
+
 /*
  * List all members of the site
  *
