@@ -4,7 +4,7 @@
  * Print forms to manage Flatnuke general configuration
  *
  * @author Marco Segato <segatom@users.sourceforge.net>
- * @version 20071014
+ * @version 20080602
  */
 function fncc_generalconf() {
 	// security conversions
@@ -20,7 +20,9 @@ function fncc_generalconf() {
 			if(eregi("^\\\$.",$conf_file[$i]))	{			// take only rows starting with '$'
 				$line_tmp = explode(";", $conf_file[$i]);	// purge strings from eventual comments on the right
 				if(eregi(" = ",$line_tmp[0])) $sep = " = ";
-					else $sep = "=";
+				elseif(eregi("= ",$line_tmp[0])) $sep = "= ";
+				elseif(eregi(" =",$line_tmp[0])) $sep = " =";
+				elseif(eregi("=",$line_tmp[0])) $sep = "=";
 				$line = explode($sep, $line_tmp[0]);			// split variable from its value
 				// build array with settings [variable name, value]
 				$settings[str_replace("$","",$line[0])] = htmlentities(trim($line[1],"\" "));
@@ -137,6 +139,32 @@ function fncc_generalconf() {
 			?><input type="radio" name="guestcomment" id="guestcomment" value="0" <?=$guestcomment_sel0?> /><?=_FNCC_NO?>
 			<input type="radio" name="guestcomment" id="guestcomment" value="1" <?=$guestcomment_sel1?> /><?=_FNCC_YES?>
 		</div>
+		<div style="margin-bottom:1em;">
+			<label for="newseditor"><?=_FNCC_NEWSEDITOR?></label><br /><?
+			if ($settings['news_editor']=="fckeditor") $news_editor = "fckeditor";
+			else $news_editor = "bbcode";
+			$bbcode_selected="";
+			$fckeditor_selected="";
+			switch($news_editor) {
+				case "bbcode": $bbcode_selected = "checked='checked'"; break;
+				case "fckeditor": $fckeditor_selected = "checked='checked'"; break;
+			}
+			?><input type="radio" name="newseditor" id="newseditor" value="bbcode" <?
+			if (!file_exists("include/plugins/editors/FCKeditor/fckeditor.php")){
+				echo "checked='checked'";
+			}
+			else echo $bbcode_selected
+			?> />bbcode
+			<input type="radio" name="newseditor" id="newseditor" value="fckeditor" 
+			<? 
+			if (file_exists("include/plugins/editors/FCKeditor/fckeditor.php")){
+				echo $fckeditor_selected;
+			}
+			else {
+				echo "disabled='disabled'";
+			}
+			?> />FCKeditor
+		</div>
 		<div style="margin-bottom:1em;">
 			<label for="remember_login"><?=_FNCC_CONFREMEMBERLOGIN?></label><br /><?
 			$remember_login_sel0 = "";
@@ -204,7 +232,7 @@ function fncc_generalconf() {
  * Read configuration files and print them ready to be managed
  *
  * @author Marco Segato <segatom@users.sourceforge.net>
- * @version 20070717
+ * @version 20080726
  *
  * @param	string	$file	File name to modify
  */
@@ -212,12 +240,27 @@ function fncc_editconffile($file) {
 	// security conversions
 	$mod  = getparam("mod", PAR_GET,  SAN_FLAT);
 	$file = getparam($file, PAR_NULL, SAN_FLAT);
+	global $news_editor;
+	if (!eregi("^fckeditor$|^bbcode$", $news_editor)) $news_editor = "bbcode";
 	// check file existance
 	if(file_exists($file)) {
 		echo "<form action=\"index.php?mod=$mod\" method=\"post\">";
-		echo "<textarea rows='20' style='width:100%;' name='conf_body'>";
-		echo htmlspecialchars(file_get_contents($file));
-		echo "</textarea>";
+		// manage MOTD file with FCKeditor		
+		if ($file==get_fn_dir("var")."/motd.php" AND $news_editor=="fckeditor" AND file_exists("include/plugins/editors/FCKeditor/fckeditor.php")) {
+			include("include/plugins/editors/FCKeditor/fckeditor.php");
+			$oFCKeditor = new FCKeditor('conf_body');
+			$oFCKeditor->BasePath = "include/plugins/editors/FCKeditor/";
+			$oFCKeditor->Value = file_get_contents($file);
+			$oFCKeditor->Width = "100%";
+			$oFCKeditor->Height = "400";
+			$oFCKeditor->ToolbarSet = "Default";
+			$oFCKeditor->Create();
+		} else {
+			// manage standard files or FCKeditor is disabled
+			echo "<textarea rows='20' style='width:100%;' name='conf_body'>";
+			echo htmlspecialchars(file_get_contents($file));
+			echo "</textarea>";
+		}
 		?><br /><br />
 		<input type="hidden" name="conf_mod" value="modbodyfile" />
 		<input type="hidden" name="conf_file" value="<?=$file?>" />
@@ -240,7 +283,7 @@ function fncc_editconffile($file) {
  * Manage news of the site (write & edit)
  *
  * @author Marco Segato <segatom@users.sourceforge.net>
- * @version 20070717
+ * @version 20080726
  */
 function fncc_managenews() {
 	// security checks
@@ -250,7 +293,9 @@ function fncc_managenews() {
 	$edit_header = "";
 	$edit_body   = "";
 	$edit_cat    = "";
-	global $sitename;
+	global $sitename, $news_editor;
+	if (!eregi("^fckeditor$|^bbcode$",$news_editor)) $news_editor="bbcode";
+	
 	// edit an old news
 	if(isset($news) AND file_exists(get_fn_dir("news")."/$news.xml")) {
 		$rewrite = $news;
@@ -261,9 +306,9 @@ function fncc_managenews() {
 		$edit_cat    = get_xml_element("fn:avatar",$fd);
 	} else {
 		// report a news with Flatnuke-Fast-News
-		$refbody  = getparam("refbody",  PAR_GET, SAN_FLAT);
-		$refurl   = getparam("refurl",   PAR_GET, SAN_FLAT);
-		$reftitle = getparam("reftitle", PAR_GET, SAN_FLAT);
+		$reftitle = utf8_decode(stripslashes(getparam("reftitle", PAR_GET, SAN_FLAT)));
+		$refbody  = utf8_decode(stripslashes(getparam("refbody",  PAR_GET, SAN_FLAT)));
+		$refurl   = getparam("refurl", PAR_GET, SAN_FLAT);
 	}
 	// options' list: write a new news, or edit an old one
 	?><select style="max-width:100%" onchange="javascript:completeAHAH.ahah('<?=get_fn_dir("sections")?>/<?=$mod?>/section.php?mod=<?=$mod?>&amp;op=fnccnews&amp;news='+this.options[this.selectedIndex].value,'fn_adminpanel','0','get');"><?
@@ -271,7 +316,7 @@ function fncc_managenews() {
 		$news_array = array();
 		$news_dir = opendir(get_fn_dir("news"));
 		while($news_file=readdir($news_dir)) {
-			if(!( $news_file=="." OR $news_file==".." ) AND (!ereg("^\.",$news_file) AND ($news_file!="CVS"))) {
+			if(!( $news_file=="." OR $news_file==".." ) AND (!ereg("^\.",$news_file) AND ($news_file!="CVS")) and eregi("xml$",get_file_extension($news_file))) {
 				array_push($news_array, str_replace(".xml","",$news_file));
 			}
 		}
@@ -312,52 +357,90 @@ function fncc_managenews() {
 			echo ">".str_replace("_"," ", ereg_replace("\..*","",$icon_array[$i]))."</option>\n";
 		}
 	echo "</select><br /><br />";
-	// bbcodes panel news HEADER
-	bbcodes_panel("head", "home", "formatting"); echo "<br />";
-	bbcodes_panel("head", "home", "emoticons"); echo "<br />";
-	bbcodes_panel("head", "home", "images"); echo "<br />";
-	echo "<b>"._INTMESSAGGIO."</b><br />";
-	echo "<textarea id='news_head' rows='20' style='width:100%;' name='head'>";
-	if(isset($refbody) AND $refbody != "") {
-		echo "$refbody\n\nLink: <a href=\"$refurl\">$refurl</a>";	// Flatnuke-Fast-News link 
-	} else echo "$edit_header";	// edit old news
-	echo "</textarea>\n<br /><br />";
-	// bbcodes panel news BODY
-	bbcodes_panel("body", "home", "formatting"); echo "<br />";
-	bbcodes_panel("body", "home", "emoticons"); echo "<br />";
-	bbcodes_panel("body", "home", "images"); echo "<br />";
-	echo "<b>"._CORPOMESSAGGIO."</b><br />";
-	echo "<textarea id='news_body' rows='20' style='width:100%;' name='body'>$edit_body</textarea><br /><br />";
+	if ($news_editor=="fckeditor" AND file_exists("include/plugins/editors/FCKeditor/fckeditor.php")) {
+		$fck_installed = TRUE;
+		if(isset($refbody) AND $refbody != "") {
+			$text = "$refbody\n\nLink: <a href=\"$refurl\">$refurl</a>";	// Flatnuke-Fast-News link 
+		} else $text = "$edit_header";	// edit old news
+		echo "<b>"._INTMESSAGGIO."</b><br />";
+		include("include/plugins/editors/FCKeditor/fckeditor.php");
+		// fckeditor panel news HEADER
+		$oFCKeditor = new FCKeditor('head');
+		$oFCKeditor->BasePath = "include/plugins/editors/FCKeditor/";
+		$oFCKeditor->Value = $text;
+		$oFCKeditor->Width = "100%";
+		$oFCKeditor->Height = "400";
+		$oFCKeditor->ToolbarSet = "Default";
+		$oFCKeditor->Create();
+		// fckeditor panel news BODY
+		echo "<b>"._CORPOMESSAGGIO."</b><br />";
+		$oFCKeditor = new FCKeditor('body');
+		$oFCKeditor->BasePath = "include/plugins/editors/FCKeditor/";
+		$oFCKeditor->Value = $edit_body;
+		$oFCKeditor->Width = "100%";
+		$oFCKeditor->Height = "500";
+		$oFCKeditor->ToolbarSet = "Default";
+		$oFCKeditor->Create();
+	} else {
+		$fck_installed = FALSE;
+		// bbcodes panel news HEADER
+		bbcodes_panel("head", "home", "formatting"); echo "<br />";
+		bbcodes_panel("head", "home", "emoticons"); echo "<br />";
+		bbcodes_panel("head", "home", "images"); echo "<br />";
+		echo "<b>"._INTMESSAGGIO."</b><br />";
+		echo "<textarea id='news_head' rows='20' style='width:100%;' name='head'>";
+		if(isset($refbody) AND $refbody != "") {
+			echo "$refbody\n\nLink: <a href=\"$refurl\">$refurl</a>";	// Flatnuke-Fast-News link 
+		} else echo "$edit_header";	// edit old news
+		echo "</textarea>\n<br /><br />";
+		// bbcodes panel news BODY
+		bbcodes_panel("body", "home", "formatting"); echo "<br />";
+		bbcodes_panel("body", "home", "emoticons"); echo "<br />";
+		bbcodes_panel("body", "home", "images"); echo "<br />";
+		echo "<b>"._CORPOMESSAGGIO."</b><br />";
+		echo "<textarea id='news_body' rows='20' style='width:100%;' name='body'>$edit_body</textarea>\n";
+	}
+	
 	// submit buttons
 	?><input type="hidden" name="conf_mod" value="savenews" />
-	<input type="hidden" name="rewrite" value="<?=$rewrite?>" />
-	<input type="submit" value="<?=_INSNOTIZIA?>" />
-	<input type="button" value="<?=_ANTEPRIMA?>" onclick='ShowHideDiv("fnpreview");' /><?
+	<input type="hidden" name="rewrite" value="<?=$rewrite?>" /><br /><br />
+	<input type="submit" value="<?=_INSNOTIZIA?>" /><?
+	if (!$fck_installed) {
+		?>&nbsp;<input type="button" value="<?=_ANTEPRIMA?>" onclick='ShowHideDiv("fnpreview");' /><?
+	}
 	if($rewrite!="false") {
 		$delurl = get_fn_dir("sections")."/$mod/section.php?mod=$mod&amp;get_act=deletenews&amp;delnews=".get_fn_dir("news")."/$news.xml";
 		echo "&nbsp;<input type=\"button\" value=\""._ELIMINA."\" onclick=\"javascript:completeAHAH.ahah('$delurl','fn_adminpanel','0','get');\" />";
 	}
-	?></form>
-	<script language="javascript">
-		getElement("news_title").onkeyup     = news_preview;
-		getElement("news_title").onmousemove = news_preview;
-		getElement("news_head").onkeyup      = news_preview;
-		getElement("news_head").onmousemove  = news_preview;
-		getElement("news_body").onkeyup      = news_preview;
-		getElement("news_body").onmousemove  = news_preview;
-		news_preview();
-	</script>
-	<br /><div id="fnpreview" name="fnpreview" style="overflow:auto;max-height:300px;visibility:visible;background-color:#F0F0F0;border:2px solid;padding:5px;border-top-color:#ffffff;border-left-color:#ffffff;border-bottom-color:#666666;border-right-color:#666666;width:100%;"></div>
-	<?
+	?></form><?
+	
+	// preview news with bbcodes
+	if (!$fck_installed) {
+		?><script language="javascript">
+			getElement("news_title").onkeyup     = news_preview;
+			getElement("news_title").onmousemove = news_preview;
+			getElement("news_head").onkeyup      = news_preview;
+			getElement("news_head").onmousemove  = news_preview;
+			getElement("news_body").onkeyup      = news_preview;
+			getElement("news_body").onmousemove  = news_preview;
+			news_preview();
+		</script>
+		<br /><div id="fnpreview" name="fnpreview"></div><?
+	}
+	
 	// Flatnuke-Fast-News link
-	echo "<br />"._FASTNEWSSTR."<br /><a href=\"javascript:if(navigator.userAgent.indexOf('Safari') >= 0){Q=getSelection();}else{Q=document.selection?document.selection.createRange().text:document.getSelection();}location.href='http://".$_SERVER["HTTP_HOST"].$_SERVER["PHP_SELF"]."?mod=news&refbody='+encodeURIComponent(Q)+'&refurl='+encodeURIComponent(location.href)+'&reftitle='+encodeURIComponent(document.title);\">$sitename &raquo; Flatnuke Fast News</a>";
+	$protocol = (isset($_SERVER['HTTPS']) AND $_SERVER['HTTPS']=="on") ? ("https://") : ("http://");
+	$dn = DirName($_SERVER['PHP_SELF'])."/";
+	$dn = str_replace("//", "/", $dn);
+	$siteurl = "$protocol".$_SERVER["HTTP_HOST"]."$dn";
+	echo "<br />"._FASTNEWSSTR."<br /><a href=\"javascript:if(navigator.userAgent.indexOf('Safari') >= 0){Q=getSelection();}else{Q=document.selection?document.selection.createRange().text:document.getSelection();}location.href='".$siteurl."index.php?mod=none_Admin&op=fnccnews&refbody='+encodeURIComponent(Q)+'&refurl='+encodeURIComponent(location.href)+'&reftitle='+encodeURIComponent(document.title);\">$sitename &raquo; Flatnuke Fast News</a>";
 }
 
 /*
  * Manage news proposed by users/visitors
  *
  * @author Marco Segato <segatom@users.sourceforge.net>
- * @version 20070721
+ * @version 20080726
  */
 function fncc_managepropnews() {
 	// security checks
@@ -367,6 +450,9 @@ function fncc_managepropnews() {
 	$edit_header = "";
 	$edit_body   = "";
 	$edit_cat    = "";
+	global $news_editor;
+	if (!eregi("^fckeditor$|^bbcode$",$news_editor)) $news_editor="bbcode";
+	
 	// load contents of the news proposed
 	if(isset($news) AND file_exists(get_fn_dir("var")."/$news.xml")) {
 		$rewrite = $news;
@@ -431,38 +517,65 @@ function fncc_managepropnews() {
 			echo ">".str_replace("_"," ", ereg_replace("\..*","",$icon_array[$i]))."</option>\n";
 		}
 	echo "</select><br /><br />";
-	// bbcodes panel news HEADER
-	bbcodes_panel("head", "home", "formatting"); echo "<br />";
-	bbcodes_panel("head", "home", "emoticons"); echo "<br />";
-	bbcodes_panel("head", "home", "images"); echo "<br />";
-	echo "<b>"._INTMESSAGGIO."</b><br />";
-	echo "<textarea id='news_head' rows='20' style='width:100%;' name='head'>";
-	echo "$edit_header";
-	echo "</textarea>\n<br /><br />";
-	// bbcodes panel news BODY
-	bbcodes_panel("body", "home", "formatting"); echo "<br />";
-	bbcodes_panel("body", "home", "emoticons"); echo "<br />";
-	bbcodes_panel("body", "home", "images"); echo "<br />";
-	echo "<b>"._CORPOMESSAGGIO."</b><br />";
-	echo "<textarea id='news_body' rows='20' style='width:100%;' name='body'>$edit_body</textarea><br /><br />";
+	if ($news_editor=="fckeditor" AND file_exists("include/plugins/editors/FCKeditor/fckeditor.php")) {
+		$fck_installed = TRUE;
+		echo "<b>"._INTMESSAGGIO."</b><br />";
+		include("include/plugins/editors/FCKeditor/fckeditor.php");
+		// fckeditor panel news HEADER
+		$oFCKeditor = new FCKeditor('head');
+		$oFCKeditor->BasePath = "include/plugins/editors/FCKeditor/";
+		$oFCKeditor->Value = $edit_header;
+		$oFCKeditor->Width = "100%";
+		$oFCKeditor->Height = "400";
+		$oFCKeditor->ToolbarSet = "Default";
+		$oFCKeditor->Create();
+		// fckeditor panel news BODY
+		echo "<b>"._CORPOMESSAGGIO."</b><br />";
+		$oFCKeditor = new FCKeditor('body');
+		$oFCKeditor->BasePath = "include/plugins/editors/FCKeditor/";
+		$oFCKeditor->Value = $edit_body;
+		$oFCKeditor->Width = "100%";
+		$oFCKeditor->Height = "500";
+		$oFCKeditor->ToolbarSet = "Default";
+		$oFCKeditor->Create();
+	} else {
+		$fck_installed = FALSE;
+		// bbcodes panel news HEADER
+		bbcodes_panel("head", "home", "formatting"); echo "<br />";
+		bbcodes_panel("head", "home", "emoticons"); echo "<br />";
+		bbcodes_panel("head", "home", "images"); echo "<br />";
+		echo "<b>"._INTMESSAGGIO."</b><br />";
+		echo "<textarea id='news_head' rows='20' style='width:100%' name='head'>$edit_header</textarea>\n<br /><br />";
+		// bbcodes panel news BODY
+		bbcodes_panel("body", "home", "formatting"); echo "<br />";
+		bbcodes_panel("body", "home", "emoticons"); echo "<br />";
+		bbcodes_panel("body", "home", "images"); echo "<br />";
+		echo "<b>"._CORPOMESSAGGIO."</b><br />";
+		echo "<textarea id='news_body' rows='20' style='width:100%' name='body'>$edit_body</textarea>\n";
+	}
 	// submit buttons
 	?><input type="hidden" name="conf_mod" value="savepropnews" />
-	<input type="hidden" name="rewrite" value="<?=$rewrite?>" />
-	<input type="submit" value="<?=_INSNOTIZIA?>" />
-	<input type="button" value="<?=_ANTEPRIMA?>" onclick='ShowHideDiv("fnpreview");' />
-	<? $delurl = get_fn_dir("sections")."/$mod/section.php?mod=$mod&amp;get_act=deletenews&amp;delnews=misc/$news.xml"; ?>
-	<input type="button" value="<?=_ELIMINA?>" onclick="javascript:completeAHAH.ahah('<?=$delurl?>','fn_adminpanel','0','get');" />
-	</form>
-	<script language="javascript">
-		getElement("news_title").onkeyup     = news_preview;
-		getElement("news_title").onmousemove = news_preview;
-		getElement("news_head").onkeyup      = news_preview;
-		getElement("news_head").onmousemove  = news_preview;
-		getElement("news_body").onkeyup      = news_preview;
-		getElement("news_body").onmousemove  = news_preview;
-		news_preview();
-	</script>
-	<br /><div id="fnpreview" name="fnpreview" style="overflow:auto;max-height:300px;visibility:visible;background-color:#F0F0F0;border:2px solid;padding:5px;border-top-color:#ffffff;border-left-color:#ffffff;border-bottom-color:#666666;border-right-color:#666666;width:100%;"></div><?
+	<input type="hidden" name="rewrite" value="<?=$rewrite?>" /><br /><br />
+	<input type="submit" value="<?=_INSNOTIZIA?>" /><?
+	if (!$fck_installed) {
+		?>&nbsp;<input type="button" value="<?=_ANTEPRIMA?>" onclick='ShowHideDiv("fnpreview");' /><?
+	}
+	$delurl = get_fn_dir("sections")."/$mod/section.php?mod=$mod&amp;get_act=deletenews&amp;delnews=misc/$news.xml"; ?>
+	&nbsp;<input type="button" value="<?=_ELIMINA?>" onclick="javascript:completeAHAH.ahah('<?=$delurl?>','fn_adminpanel','0','get');" />
+	</form><?
+	// preview news with bbcodes
+	if (!$fck_installed) {
+		?><script language="javascript">
+			getElement("news_title").onkeyup     = news_preview;
+			getElement("news_title").onmousemove = news_preview;
+			getElement("news_head").onkeyup      = news_preview;
+			getElement("news_head").onmousemove  = news_preview;
+			getElement("news_body").onkeyup      = news_preview;
+			getElement("news_body").onmousemove  = news_preview;
+			news_preview();
+		</script>
+		<br /><div id="fnpreview" name="fnpreview"></div><?
+	}
 }
 
 /*
@@ -531,6 +644,210 @@ function fncc_editpoll() {
 	<?
 }
 
+/*
+ * Print forms to manage Flatnuke general configuration
+ *
+ * @author Marco Segato <segatom@users.sourceforge.net>
+ * @version 20080607
+ */
+function fncc_fdplusconf() {
+	// security conversions
+	$mod = getparam("mod", PAR_GET, SAN_FLAT);
+	// check file existance
+	$file = "download/fdconfig.php";
+	if(file_exists($file)) {
+		echo "<form action=\"index.php?mod=$mod\" method=\"post\">";
+		// scan configuration file to find all settings
+		$settings  = array();
+		$conf_file = file($file);
+		for($i=0;$i<count($conf_file);$i++) {
+			if(eregi("^\\\$.",$conf_file[$i]))	{			// take only rows starting with '$'
+				$line_tmp = explode(";", $conf_file[$i]);	// purge strings from eventual comments on the right
+				if(eregi(" = ",$line_tmp[0])) $sep = " = ";
+				elseif(eregi("= ",$line_tmp[0])) $sep = "= ";
+				elseif(eregi(" =",$line_tmp[0])) $sep = " =";
+				elseif(eregi("=",$line_tmp[0])) $sep = "=";
+				$line = explode($sep, $line_tmp[0]);			// split variable from its value
+				// build array with settings [variable name, value]
+				$settings[str_replace("$","",$line[0])] = htmlentities(trim($line[1],"\" "));
+			}
+		}	//print_r($settings);	//-> TEST
+		// scan for installed mime icon sets
+		$icons_array = array();
+		$icons_num   = 0;
+		foreach (glob("images/mime/*") as $icon_one){
+			if(is_dir($icon_one) AND !eregi("CVS",$icon_one) AND $icon_one!="." AND $icon_one!="..") {
+				$icons_array[$icons_num] = $icon_one;
+				$icons_num++;
+			}
+		}
+		if($icons_num>0) {
+			sort($icons_array);
+		}	//print_r($icons_array);	//-> TEST
+		?>
+		<div style="margin-bottom:1em;">
+			<label for="extensions"><?=_FNCC_FDPEXTENSIONS?></label><br />
+			<input type="text" name="extensions" id="extensions" style="width:100%;" maxlength="300" value="<?=$settings['extensions']?>" />
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="maxFileSize"><?=_FNCC_FDPMAXFILESIZE?></label><br />
+			<input type="text" name="maxFileSize" id="maxFileSize" style="width:100%;" maxlength="500" value="<?=$settings['maxFileSize']?>" />
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="icon_style"><?=_FNCC_FDPICONSTYLE?></label><br /><?
+			// print the list of available mime icon sets
+			foreach ($icons_array as $myicon) {
+				$myicon = eregi_replace("^images/mime/","",$myicon);
+				$checked = ($settings['icon_style'] == $myicon) ? ("checked='checked'") : ("");
+				echo "<input type='radio' $checked name='icon_style' id='icon_style' value='$myicon' />$myicon&nbsp;&nbsp;";
+			}
+		?></div>
+		<div style="margin-bottom:1em;">
+			<label for="newfiletime"><?=_FNCC_FDPNEWFILETIME?></label><br />
+			<input type="text" name="newfiletime" id="newfiletime" style="width:100%;" maxlength="1500" value="<?=$settings['newfiletime']?>" />
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="automd5"><?=_FNCC_FDPAUTOMD5?></label><br /><?
+			$automd5_sel0 = "";
+			$automd5_sel1 = "";
+			switch($settings['automd5']) {
+				case 0: $automd5_sel0 = "checked='checked'"; break;
+				case 1: $automd5_sel1 = "checked='checked'"; break;
+			}
+			?><input type="radio" name="automd5" id="automd5" value="0" <?=$automd5_sel0?> /><?=_FNCC_NO?>
+			<input type="radio" name="automd5" id="automd5" value="1" <?=$automd5_sel1?> /><?=_FNCC_YES?>
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="autosha1"><?=_FNCC_FDPAUTOSHA1?></label><br /><?
+			$autosha1_sel0 = "";
+			$autosha1_sel1 = "";
+			switch($settings['autosha1']) {
+				case 0: $autosha1_sel0 = "checked='checked'"; break;
+				case 1: $autosha1_sel1 = "checked='checked'"; break;
+			}
+			?><input type="radio" name="autosha1" id="autosha1" value="0" <?=$autosha1_sel0?> /><?=_FNCC_NO?>
+			<input type="radio" name="autosha1" id="autosha1" value="1" <?=$autosha1_sel1?> /><?=_FNCC_YES?>
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="showuploader"><?=_FNCC_FDPSHOWUPLOADER?></label><br /><?
+			$showuploader_sel0 = "";
+			$showuploader_sel1 = "";
+			switch($settings['showuploader']) {
+				case 0: $showuploader_sel0 = "checked='checked'"; break;
+				case 1: $showuploader_sel1 = "checked='checked'"; break;
+			}
+			?><input type="radio" name="showuploader" id="showuploader" value="0" <?=$showuploader_sel0?> /><?=_FNCC_NO?>
+			<input type="radio" name="showuploader" id="showuploader" value="1" <?=$showuploader_sel1?> /><?=_FNCC_YES?>
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="extsig"><?=_FNCC_FDPGPG?></label><br />
+			<input type="text" name="extsig" id="extsig" style="width:100%;" maxlength="4" value="<?=$settings['extsig']?>" />
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="extscreenshot"><?=_FNCC_FDPSCREENSHOTS?></label><br />
+			<input type="text" name="extscreenshot" id="extscreenshot" style="width:100%;" maxlength="4" value="<?=$settings['extscreenshot']?>" />
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="admins"><?=_FNCC_FDPADMINS?></label><br />
+			<input type="text" name="admins" id="admins" style="width:100%;" maxlength="200" value="<?=$settings['admins']?>" />
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="enable_admin_options"><?=_FNCC_FDPADMINOPTOK?></label><br /><?
+			$enable_admin_options_sel0 = "";
+			$enable_admin_options_sel1 = "";
+			switch($settings['enable_admin_options']) {
+				case 0: $enable_admin_options_sel0 = "checked='checked'"; break;
+				case 1: $enable_admin_options_sel1 = "checked='checked'"; break;
+			}
+			?><input type="radio" name="enable_admin_options" id="enable_admin_options" value="0" <?=$enable_admin_options_sel0?> /><?=_FNCC_NO?>
+			<input type="radio" name="enable_admin_options" id="enable_admin_options" value="1" <?=$enable_admin_options_sel1?> /><?=_FNCC_YES?>
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="showdownloadlink"><?=_FNCC_FDPSHOWLINK?></label><br /><?
+			$showdownloadlink_sel0 = "";
+			$showdownloadlink_sel1 = "";
+			switch($settings['showdownloadlink']) {
+				case 0: $showdownloadlink_sel0 = "checked='checked'"; break;
+				case 1: $showdownloadlink_sel1 = "checked='checked'"; break;
+			}
+			?><input type="radio" name="showdownloadlink" id="showdownloadlink" value="0" <?=$showdownloadlink_sel0?> /><?=_FNCC_NO?>
+			<input type="radio" name="showdownloadlink" id="showdownloadlink" value="1" <?=$showdownloadlink_sel1?> /><?=_FNCC_YES?>
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="overview_show_files"><?=_FNCC_FDPFILELIST?></label><br /><?
+			$overview_show_files_sel0 = "";
+			$overview_show_files_sel1 = "";
+			switch($settings['overview_show_files']) {
+				case 0: $overview_show_files_sel0 = "checked='checked'"; break;
+				case 1: $overview_show_files_sel1 = "checked='checked'"; break;
+			}
+			?><input type="radio" name="overview_show_files" id="overview_show_files" value="0" <?=$overview_show_files_sel0?> /><?=_FNCC_NO?>
+			<input type="radio" name="overview_show_files" id="overview_show_files" value="1" <?=$overview_show_files_sel1?> /><?=_FNCC_YES?>
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="section_show_header"><?=_FNCC_FDPSUMMARY?></label><br /><?
+			$section_show_header_sel0 = "";
+			$section_show_header_sel1 = "";
+			switch($settings['section_show_header']) {
+				case 0: $section_show_header_sel0 = "checked='checked'"; break;
+				case 1: $section_show_header_sel1 = "checked='checked'"; break;
+			}
+			?><input type="radio" name="section_show_header" id="section_show_header" value="0" <?=$section_show_header_sel0?> /><?=_FNCC_NO?>
+			<input type="radio" name="section_show_header" id="section_show_header" value="1" <?=$section_show_header_sel1?> /><?=_FNCC_YES?>
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="defaultvoteon"><?=_FNCC_FDPVOTE?></label><br /><?
+			$defaultvoteon_sel0 = "";
+			$defaultvoteon_sel1 = "";
+			switch($settings['defaultvoteon']) {
+				case 0: $defaultvoteon_sel0 = "checked='checked'"; break;
+				case 1: $defaultvoteon_sel1 = "checked='checked'"; break;
+			}
+			?><input type="radio" name="defaultvoteon" id="defaultvoteon" value="0" <?=$defaultvoteon_sel0?> /><?=_FNCC_NO?>
+			<input type="radio" name="defaultvoteon" id="defaultvoteon" value="1" <?=$defaultvoteon_sel1?> /><?=_FNCC_YES?>
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="usermaxFileSize"><?=_FNCC_FDPMAXUSERSIZE?></label><br />
+			<input type="text" name="usermaxFileSize" id="usermaxFileSize" style="width:100%;" maxlength="500" value="<?=$settings['usermaxFileSize']?>" />
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="userfilelimit"><?=_FNCC_FDPNUMWAITING?></label><br />
+			<input type="text" name="userfilelimit" id="userfilelimit" style="width:100%;" maxlength="500" value="<?=$settings['userfilelimit']?>" />
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="userwaitingfile"><?=_FNCC_FDPFILEWAITING?></label><br />
+			<input type="text" name="userwaitingfile" id="userwaitingfile" style="width:100%;" maxlength="500" value="<?=$settings['userwaitingfile']?>" readonly="readonly" />
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="userblacklist"><?=_FNCC_FDPBLACKLIST?></label><br />
+			<input type="text" name="userblacklist" id="userblacklist" style="width:100%;" maxlength="500" value="<?=$settings['userblacklist']?>" />
+		</div>
+		<div style="margin-bottom:1em;">
+			<label for="minlevel"><?=_FNCC_FDPMINLEVEL?></label><br />
+			<select name="minlevel" id="minlevel"><?
+				for($i=0;$i<=10;$i++) {
+					$selected = ($settings['minlevel']==$i) ? ("selected='selected'") : ("");
+					echo "<option value='$i' $selected>$i</option>";
+				}
+			?></select>
+		</div>
+		<input type="hidden" name="conf_mod" value="moddownconf" />
+		<input type="hidden" name="conf_file" value="<?=$file?>" />
+		<?
+		// check writing permissions
+		if(is_writeable($file))	{
+			?><div align="center" style="font-weight:bold;">
+				<?=_FNCC_WARNINGDOC?><br /><br /><input type="submit" value="<?=_MODIFICA?>" />
+			</div><?
+		} else {
+			?><div align="center" style="font-weight:bold;font-color:red;">
+				<?=_FNCC_WARNINGRIGHTS?>
+			</div><? 
+		}
+		?></form><?
+	} else echo "<div align='center' style='font-weight:bold;font-color:red;'>"._FNCC_WARNINGNOFILE."</div>";
+}
+
 /*
  * List all members of the site, with the possibility
  * to list them in order by name or by time
@@ -608,6 +925,7 @@ function fncc_userslist() {
  * @version 20070716
  */
 function fncc_newuserprofile() {
+	global $reguser, $action;
 	// security conversions
 	$mod   = getparam("mod", PAR_GET, SAN_FLAT);
 	// print fields to fill
@@ -656,6 +974,22 @@ function fncc_newuserprofile() {
 		<td style="<?=$style1?>"><label for="prov"><?=_FPROV?></label></td>
 		<td style="<?=$style2?>"><input name="prov" type="text" id="prov" /></td>
 	</tr>
+	<tr>
+		<td style="<?=$style1?>"><label for="jabber">Jabber / Google Talk</label></td>
+		<td style="<?=$style2?>"><input name="jabber" type="text" id="jabber" /></td>
+	</tr>
+	<tr>
+		<td style="<?=$style1?>"><label for="skype">Skype</label></td>
+		<td style="<?=$style2?>"><input name="skype" type="text" id="skype" /></td>
+	</tr>
+	<tr>
+		<td style="<?=$style1?>"><label for="icq">ICQ</label></td>
+		<td style="<?=$style2?>"><input name="icq" type="text" id="icq" /></td>
+	</tr>
+	<tr>
+		<td style="<?=$style1?>"><label for="msn">MSN</label></td>
+		<td style="<?=$style2?>"><input name="msn" type="text" id="msn" /></td>
+	</tr>
 	<tr>
 		<td style="<?=$style1?>"><label for="ava"><?=_FAVAT?></label></td>
 		<td style="<?=$style2?>">
@@ -685,6 +1019,10 @@ function fncc_newuserprofile() {
 		<td style="<?=$style1?>"><label for="firma"><?=_FFIRMA?></label></td>
 		<td style="<?=$style2?>"><textarea name="firma" id="firma" rows="5" cols="23"></textarea></td>
 	</tr>
+	<tr>
+		<td style="<?=$style1?>"><label for="presentation"><?=_FNPRESENTATION?></label></td>
+		<td style="<?=$style2?>"><textarea name="presentation" id="presentation" rows="5" cols="23"></textarea></td>
+	</tr>
 	<tr>
 		<td style="<?=$style1?>"><label for="level"><?=_LEVEL?></label></td>
 		<td style="<?=$style2?>">
@@ -981,7 +1319,7 @@ function fncc_managelogs() {
  * Manage Flatnuke blacklists
  *
  * @author Marco Segato <segatom@users.sourceforge.net>
- * @version 20070721
+ * @version 20080607
  */
 function fncc_manageblacklists() {
 	// security checks
@@ -997,7 +1335,7 @@ function fncc_manageblacklists() {
 	$lists_array = array();
 	$lists_dir = opendir("include/blacklists");
 	while($lists_file=readdir($lists_dir)) {
-		if($lists_file!="." AND $lists_file!="..") {
+		if($lists_file!="." AND $lists_file!=".." AND eregi("php$",get_file_extension($lists_file))) {
 			array_push($lists_array, str_replace(".php","",$lists_file));
 		}
 	} //echo "<pre>";print_r($lists_array);echo "</pre>";	//-> TEST
