@@ -4,7 +4,7 @@
  * Save Flatnuke general configuration
  *
  * @author Marco Segato <segatom@users.sourceforge.net>
- * @version 20071014
+ * @version 20080601
  */
 function fncc_modgeneralconf() {
 	// security checks
@@ -28,12 +28,13 @@ function fncc_modgeneralconf() {
 	$postperpage       = getparam("postperpage",      PAR_POST, SAN_FLAT);
 	$memberperpage     = getparam("memberperpage",    PAR_POST, SAN_FLAT);
 	$forum_moderators  = getparam("forum_moderators", PAR_POST, SAN_FLAT);
+	$news_editor       = getparam("newseditor",       PAR_POST, SAN_FLAT);
 	// build new file
 	$file = file($conf_file);
 	$new_file = "";
 	for($id=0;$id<count($file);$id++) {
 		if(eregi("^\\$"."sitename",$file[$id])) {
-			$new_file .= "$"."sitename = \"".$sitename."\";\n";
+			$new_file .= "$"."sitename = \"".stripslashes($sitename)."\";\n";
 		} elseif(eregi("^\\$"."sitedescription",$file[$id])) {
 			$new_file .= "$"."sitedescription = \"".$sitedescription."\";\n";
 		} elseif(eregi("^\\$"."keywords",$file[$id])) {
@@ -70,6 +71,8 @@ function fncc_modgeneralconf() {
 			$new_file .= "$"."memberperpage = ".$memberperpage.";\n";
 		} elseif(eregi("^\\$"."forum_moderators",$file[$id])) {
 			$new_file .= "$"."forum_moderators = \"".$forum_moderators."\";\n";
+		} elseif(eregi("^\\$"."news_editor",$file[$id])) {
+			$new_file .= "$"."news_editor = \"".$news_editor."\";\n";
 		} else $new_file .= $file[$id];
 	}
 	// write the new file
@@ -106,7 +109,7 @@ function fncc_modbodyfile() {
  * Save a news
  *
  * @author Marco Segato <segatom@users.sourceforge.net>
- * @version 20070724
+ * @version 20080630
  */
 function fncc_savenews() {
 	// security checks
@@ -120,9 +123,16 @@ function fncc_savenews() {
 	$myfile  = stripslashes(htmlspecialchars($file));
 	$mytitle = stripslashes(htmlspecialchars($title));
 	$myicon  = stripslashes(htmlspecialchars($icon));
-	$head    = str_replace("\n","<br />",$head);
+	
+	global $news_editor;
+	if (!eregi("^fckeditor$|^bbcode$",$news_editor)) $news_editor="bbcode";
+	//fix \n if bbcode is used instead of fckeditor
+	if (!($news_editor=="fckeditor" and file_exists("include/plugins/editors/FCKeditor/fckeditor.php"))){
+		$head    = str_replace("\n","<br />",$head);
+		$body    = str_replace("\n","<br />",$body);
+	}
+	
 	$head    = str_replace("\r","",$head);
-	$body    = str_replace("\n","<br />",$body);
 	$body    = str_replace("\r","",$body);
 	$mybody  = tag2html($body, "home");
 	$myhead  = tag2html($head, "home");
@@ -155,6 +165,7 @@ function fncc_savenews() {
 			fnwrite($newfile, $string, "w", array("nonull"));
 			fnlog("News", $ip."||".get_username()."||News $myfile modified.");
 		}
+		load_php_code("include/autoexec.d/news");
 	} else {
 		fnlog("Security", "$ip||".get_username()."||Tried to write a news.");
 	}
@@ -164,7 +175,7 @@ function fncc_savenews() {
  * Save news proposed by users
  *
  * @author Marco Segato <segatom@users.sourceforge.net>
- * @version 20070720
+ * @version 20080630
  */
 function fncc_savepropnews() {
 	// security checks
@@ -201,6 +212,7 @@ function fncc_savepropnews() {
 			fnlog("News", $ip."||".get_username()."||News $newfile proposed by a user has been published.");
 			// update my RSS feeds
 			generate_RSS();
+			load_php_code("include/autoexec.d/news");
 		}
 	} else {
 		fnlog("Security", "$ip||".get_username()."||Tried to publish a news proposed.");
@@ -211,7 +223,7 @@ function fncc_savepropnews() {
  * Delete news' file
  *
  * @author Marco Segato <segatom@users.sourceforge.net>
- * @version 20070719
+ * @version 20080630
  */
 function fncc_delnews() {
 	// security checks
@@ -222,6 +234,7 @@ function fncc_delnews() {
 	if(is_admin() AND file_exists($mynews)) {
 		unlink($mynews);
 		fnlog("Site maintenance", "$ip||".get_username()."||Deleted news $mynews.");
+		load_php_code("include/autoexec.d/news");
 	} else {
 		fnlog("Security", "$ip||".get_username()."||Tried to delete the file $mynews.");
 	}
@@ -313,6 +326,91 @@ function fncc_archpoll() {
 	}
 }
 
+/*
+ * Save FdPlus general configuration
+ *
+ * @author Marco Segato <segatom@users.sourceforge.net>
+ * @version 20080607
+ */
+function fncc_savedownconf() {
+	// security checks
+	$conf_file            = getparam("conf_file",            PAR_POST, SAN_FLAT);
+	$extensions           = getparam("extensions",           PAR_POST, SAN_FLAT);
+	$maxFileSize          = getparam("maxFileSize",          PAR_POST, SAN_FLAT);
+	$icon_style           = getparam("icon_style",           PAR_POST, SAN_FLAT);
+	$newfiletime          = getparam("newfiletime",          PAR_POST, SAN_FLAT);
+	$automd5              = getparam("automd5",              PAR_POST, SAN_FLAT);
+	$autosha1             = getparam("autosha1",             PAR_POST, SAN_FLAT);
+	$showuploader         = getparam("showuploader",         PAR_POST, SAN_FLAT);
+	$extsig               = getparam("extsig",               PAR_POST, SAN_FLAT);
+	$extscreenshot        = getparam("extscreenshot",        PAR_POST, SAN_FLAT);
+	$admins               = getparam("admins",               PAR_POST, SAN_FLAT);
+	$enable_admin_options = getparam("enable_admin_options", PAR_POST, SAN_FLAT);
+	$showdownloadlink     = getparam("showdownloadlink",     PAR_POST, SAN_FLAT);
+	$overview_show_files  = getparam("overview_show_files",  PAR_POST, SAN_FLAT);
+	$section_show_header  = getparam("section_show_header",  PAR_POST, SAN_FLAT);
+	$defaultvoteon        = getparam("defaultvoteon",        PAR_POST, SAN_FLAT);
+	$usermaxFileSize      = getparam("usermaxFileSize",      PAR_POST, SAN_FLAT);
+	$userfilelimit        = getparam("userfilelimit",        PAR_POST, SAN_FLAT);
+	$userwaitingfile      = getparam("userwaitingfile",      PAR_POST, SAN_FLAT);
+	$userblacklist        = getparam("userblacklist",        PAR_POST, SAN_FLAT);
+	$minlevel             = getparam("minlevel",             PAR_POST, SAN_FLAT);
+	// build new file
+	$file = file($conf_file);
+	$new_file = "";
+	for($id=0;$id<count($file);$id++) {
+		if(eregi("^\\$"."extensions",$file[$id])) {
+			$new_file .= "$"."extensions = \"".str_replace(" ", "", $extensions)."\";\n";
+		} elseif(eregi("^\\$"."maxFileSize",$file[$id])) {
+			$new_file .= "$"."maxFileSize = \"".$maxFileSize."\";\n";
+		} elseif(eregi("^\\$"."icon_style",$file[$id])) {
+			$new_file .= "$"."icon_style = \"".$icon_style."\";\n";
+		} elseif(eregi("^\\$"."newfiletime",$file[$id])) {
+			$new_file .= "$"."newfiletime = ".$newfiletime.";\n";
+		} elseif(eregi("^\\$"."automd5",$file[$id])) {
+			$new_file .= "$"."automd5 = ".$automd5.";\n";
+		} elseif(eregi("^\\$"."autosha1",$file[$id])) {
+			$new_file .= "$"."autosha1 = ".$autosha1.";\n";
+		} elseif(eregi("^\\$"."showuploader",$file[$id])) {
+			$new_file .= "$"."showuploader = \"".$showuploader."\";\n";
+		} elseif(eregi("^\\$"."extsig",$file[$id])) {
+			$new_file .= "$"."extsig = \"".$extsig."\";\n";
+		} elseif(eregi("^\\$"."extscreenshot",$file[$id])) {
+			$new_file .= "$"."extscreenshot = \"".$extscreenshot."\";\n";
+		} elseif(eregi("^\\$"."admins",$file[$id])) {
+			$new_file .= "$"."admins = \"".str_replace(" ", "", $admins)."\";\n";
+		} elseif(eregi("^\\$"."enable_admin_options",$file[$id])) {
+			$new_file .= "$"."enable_admin_options = \"".$enable_admin_options."\";\n";
+		} elseif(eregi("^\\$"."showdownloadlink",$file[$id])) {
+			$new_file .= "$"."showdownloadlink = \"".$showdownloadlink."\";\n";
+		} elseif(eregi("^\\$"."overview_show_files",$file[$id])) {
+			$new_file .= "$"."overview_show_files = \"".$overview_show_files."\";\n";
+		} elseif(eregi("^\\$"."section_show_header",$file[$id])) {
+			$new_file .= "$"."section_show_header = \"".$section_show_header."\";\n";
+		} elseif(eregi("^\\$"."defaultvoteon",$file[$id])) {
+			$new_file .= "$"."defaultvoteon = \"".$defaultvoteon."\";\n";
+		} elseif(eregi("^\\$"."usermaxFileSize",$file[$id])) {
+			$new_file .= "$"."usermaxFileSize = ".$usermaxFileSize.";\n";
+		} elseif(eregi("^\\$"."userfilelimit",$file[$id])) {
+			$new_file .= "$"."userfilelimit = \"".$userfilelimit."\";\n";
+		} elseif(eregi("^\\$"."userwaitingfile",$file[$id])) {
+			$new_file .= "$"."userwaitingfile = \"".$userwaitingfile."\";\n";
+		} elseif(eregi("^\\$"."userblacklist",$file[$id])) {
+			$new_file .= "$"."userblacklist = \"".str_replace(" ", "", $userblacklist)."\";\n";
+		} elseif(eregi("^\\$"."minlevel",$file[$id])) {
+			$new_file .= "$"."minlevel = \"".$minlevel."\";\n";
+		} else $new_file .= $file[$id];
+	}
+	// write the new file
+	$ip = getparam("REMOTE_ADDR", PAR_SERVER, SAN_NULL);
+	if(is_admin()) {
+		fnwrite($conf_file, $new_file, "wb", array("nonull"));
+		fnlog("Site maintenance", "$ip||".get_username()."||FdPlus configuration changed.");
+	} else {
+		fnlog("Security", "$ip||".get_username()."||Tried to change FdPlus configuration.");
+	}
+}
+
 /*
  * Save new user profile
  *
@@ -327,6 +425,7 @@ function fncc_saveprofile() {
 	$data['password']   = md5($_POST['regpass']);
 	$data['name']       = $_POST['anag'];
 	$data['mail']       = $_POST['email'];
+	//may be not inizialized
 	$data['hiddenmail'] = $_POST['hiddenmail'];
 	$data['homepage']   = $_POST['homep'];
 	$data['work']       = $_POST['prof'];
@@ -334,6 +433,11 @@ function fncc_saveprofile() {
 	$data['avatar']     = $_POST['ava'];
 	$data['sign']       = $_POST['firma'];
 	$data['level']      = $_POST['level'];
+	$data['jabber']     = $_POST['jabber'];
+	$data['skype']      = $_POST['skype'];
+	$data['icq']        = $_POST['icq'];
+	$data['msn']        = $_POST['msn'];
+	$data['presentation'] = $_POST['presentation'];
 	// manage avatar
 	if(isset($_POST['url_avatar']) AND eregi("(jpg|jpeg|png|gif)",get_file_extension($_POST['url_avatar'])) ) {
 		$data['avatar'] = $_POST['url_avatar'];
@@ -414,7 +518,7 @@ function fncc_sendactivation() {
 	$url_act = str_replace(get_fn_dir("sections")."/$mod/section.php", "index.php", $url_act);
 	if(is_admin() AND file_exists(get_waiting_users_dir()."/$user.php")) {
 		$message = _IST_REG_MAIL."\n\n$url_act";
-		if(mail($mail, _COMP_REG_MAIL." $sitename", $message,"FROM: $sitename <noreply@noreply>\n")) {
+		if(mail($mail, _COMP_REG_MAIL." $sitename", $message,"FROM: $sitename <noreply@noreply>\r\nX-Mailer: Flatnuke on PHP/".phpversion())) {
 			fnlog("Site maintenance", $ip."||".get_username()."||Activation mail sent for $user.");
 		} else {
 			echo "<p>"._ACTIVATIONMAILNOTSENT."</p>";
