@@ -1,4 +1,4 @@
-<? 
+<?
 
 /************************************************************************/
 /* FlatNuke - Flat Text Based Content Management System                 */
@@ -12,6 +12,10 @@
 /* the Free Software Foundation; either version 2 of the License.       */
 /************************************************************************/
 
+if (eregi("section.php",$_SERVER['PHP_SELF']))
+	{ Header("Location: ../../index.php");
+	die();
+	}
 
 generate_RSS();
 ?>
