@@ -347,7 +347,6 @@ function view_profile($user=""){
 		<td style="<?=$style2?>"><? echo tag2html($profile['presentation'],"forum"); ?></td>
 		</tr>
 		<tr>
-		<tr>
 		<td style="<?=$style1?>"><b><?=_LEVEL?>:</b></td>
 		<td style="<?=$style2?>"><?=$profile['level']?></td>
 		</tr>
@@ -566,8 +565,9 @@ function save_profile(){
 // 	$tmpdata = array();
 // 	$tmpdata = load_user_profile($nome);
 // 	$level = $tmpdata['level'];
-	if(isset($_POST['level'])) $level=$_POST['level'];
+	if(isset($_POST['level'])) $level=getparam("level",PAR_POST,SAN_FLAT);
 		else $level="";
+	if(!is_numeric($level)) $level="";
 
 	$myforum=str_replace("\r","",str_replace("\n","",$myforum));
 	$myforum=str_replace(chr(10),"",str_replace(chr(13),"",$myforum));
