@@ -105,7 +105,7 @@ function view_search_interface(){
 			$plugin_name ="";
 			$plugin_name = eregi_replace("\.php$","",basename($plugin));
 			if (eregi("^none_",$plugin_name)) continue;
-			echo "<option value=\"$plugin_name\">".eregi_replace("^[0-9][0-9]_","",$plugin_name)."</option>\n";
+			echo "<option value=\"$plugin_name\">".eregi_replace("^[0-9]*_","",$plugin_name)."</option>\n";
 		}
 	//gestisci plugins
 	?>
@@ -122,10 +122,10 @@ function view_search_interface(){
 
 /**
  * Cerca $pattern nella stringa $string secondo il metodo $method.
- * Questa funzione  pensata per essere usata dai vari plugin
+ * Questa funzione e' pensata per essere usata dai vari plugin
  * @param string $pattern la stringa da cercare
  * @param string $string la stringa in cui cercare
- * @param string $method il metodo di ricerca. Pu essere "OR" oppure "AND"
+ * @param string $method il metodo di ricerca. Puo' essere "OR" oppure "AND"
  * @return TRUE se pattern viene trovato, FALSE in caso contrario
  * @author Aldo Boccacci
  * @since 2.5.8
