@@ -70,10 +70,10 @@ for ($j=1 ;$j<count($years); $j++){
   // Lettura del file contenente le info generali
   if (file_exists("misc/flatstat/$years[$j]/generale.php")){
     $fd = file ("misc/flatstat/$years[$j]/generale.php");
-    for ($i =0 ; $i<count($fd)-1; $i++){
+    for ($i =0 ; $i<count($fd); $i++){
       $tmp=explode("|",$fd[$i]);
       $tmp = str_replace("\n","",$tmp[1]);
-      // Se il file generale che sta leggendo  quello selezionato
+      // Se il file generale che sta leggendo e' quello selezionato
       // Aggiunge le visite ad un'array contente il rispettivo mese
       // Aggiunge le visite al totale dell'anno
       if ($years[$j]==$yearSel) {
@@ -114,7 +114,7 @@ for ($j=1 ;$j<count($years); $j++){
             <td width=\"20%\" valign=\"top\">
               $yearSel:<br />";
               for ($i=0;$i < count($months); $i++){
-                // Se  il mese selezionato
+                // Se e' il mese selezionato
                 // Stampa il nome del mese
                 // Altrimenti, stampa il nome del mese e lo linka alle relative statistiche
                 if ($i+1==$monthSel){
@@ -307,7 +307,7 @@ for ($j=1 ;$j<count($years); $j++){
           <td width=\"20%\" valign=\"top\">
             Anno:<br />";
             for ($i=1;$i < count($years); $i++){
-              // Se  l'anno selezionato
+              // Se e' l'anno selezionato
               // Stampa il nome dell'anno
               // Altrimenti, stampa il nome dell'anno e lo linka alle relative statistiche
               if ($years[$i]==$yearSel){
@@ -378,7 +378,7 @@ for ($j=1 ;$j<count($years); $j++){
           <table width=\"95%\" border=\"0\" cellspacing=\"0\" cellpadding=\"5\">
           <tbody>
           ";
-          for ($i=0; $i<10;$i++){
+          for ($i=0; $i<10 AND $i<count($fd); $i++){
             $string = $data_array["referer"][$i];
             $referer = "";
             // Se la stringa supera gli 80 caratteri, viene suddivisa in sottostringhe
